# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from zitadel_client.models.beta_web_key_service_any import BetaWebKeyServiceAny
from typing import Optional, Set
from typing_extensions import Self

class BetaWebKeyServiceConnectError(BaseModel):
    """
    Error type returned by Connect: https://connectrpc.com/docs/go/errors/#http-representation
    """ # noqa: E501
    code: Optional[StrictStr] = Field(default=None, description="The status code, which should be an enum value of [google.rpc.Code][google.rpc.Code].")
    message: Optional[StrictStr] = Field(default=None, description="A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the [google.rpc.Status.details][google.rpc.Status.details] field, or localized by the client.")
    details: Optional[List[BetaWebKeyServiceAny]] = Field(default=None, description="A list of messages that carry the error details. There is no limit on the number of messages.")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["code", "message", "details"]

    @field_validator('code')
    def code_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['canceled', 'unknown', 'invalid_argument', 'deadline_exceeded', 'not_found', 'already_exists', 'permission_denied', 'resource_exhausted', 'failed_precondition', 'aborted', 'out_of_range', 'unimplemented', 'internal', 'unavailable', 'data_loss', 'unauthenticated']):
            raise ValueError("must be one of enum values ('canceled', 'unknown', 'invalid_argument', 'deadline_exceeded', 'not_found', 'already_exists', 'permission_denied', 'resource_exhausted', 'failed_precondition', 'aborted', 'out_of_range', 'unimplemented', 'internal', 'unavailable', 'data_loss', 'unauthenticated')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BetaWebKeyServiceConnectError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in details (list)
        _items = []
        if self.details:
            for _item_details in self.details:
                if _item_details:
                    _items.append(_item_details.to_dict())
            _dict['details'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BetaWebKeyServiceConnectError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "code": obj.get("code"),
            "message": obj.get("message"),
            "details": [BetaWebKeyServiceAny.from_dict(_item) for _item in obj["details"]] if obj.get("details") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

# flake8: noqa
"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from zitadel_client.models.action_service_any import ActionServiceAny
from zitadel_client.models.action_service_condition import ActionServiceCondition
from zitadel_client.models.action_service_connect_error import ActionServiceConnectError
from zitadel_client.models.action_service_create_target_request import ActionServiceCreateTargetRequest
from zitadel_client.models.action_service_create_target_response import ActionServiceCreateTargetResponse
from zitadel_client.models.action_service_delete_target_request import ActionServiceDeleteTargetRequest
from zitadel_client.models.action_service_delete_target_response import ActionServiceDeleteTargetResponse
from zitadel_client.models.action_service_event_execution import ActionServiceEventExecution
from zitadel_client.models.action_service_execution import ActionServiceExecution
from zitadel_client.models.action_service_execution_field_name import ActionServiceExecutionFieldName
from zitadel_client.models.action_service_execution_search_filter import ActionServiceExecutionSearchFilter
from zitadel_client.models.action_service_execution_type import ActionServiceExecutionType
from zitadel_client.models.action_service_execution_type_filter import ActionServiceExecutionTypeFilter
from zitadel_client.models.action_service_function_execution import ActionServiceFunctionExecution
from zitadel_client.models.action_service_get_target_request import ActionServiceGetTargetRequest
from zitadel_client.models.action_service_get_target_response import ActionServiceGetTargetResponse
from zitadel_client.models.action_service_in_conditions_filter import ActionServiceInConditionsFilter
from zitadel_client.models.action_service_in_target_ids_filter import ActionServiceInTargetIDsFilter
from zitadel_client.models.action_service_list_execution_functions_response import ActionServiceListExecutionFunctionsResponse
from zitadel_client.models.action_service_list_execution_methods_response import ActionServiceListExecutionMethodsResponse
from zitadel_client.models.action_service_list_execution_services_response import ActionServiceListExecutionServicesResponse
from zitadel_client.models.action_service_list_executions_request import ActionServiceListExecutionsRequest
from zitadel_client.models.action_service_list_executions_response import ActionServiceListExecutionsResponse
from zitadel_client.models.action_service_list_targets_request import ActionServiceListTargetsRequest
from zitadel_client.models.action_service_list_targets_response import ActionServiceListTargetsResponse
from zitadel_client.models.action_service_pagination_request import ActionServicePaginationRequest
from zitadel_client.models.action_service_pagination_response import ActionServicePaginationResponse
from zitadel_client.models.action_service_rest_call import ActionServiceRESTCall
from zitadel_client.models.action_service_rest_webhook import ActionServiceRESTWebhook
from zitadel_client.models.action_service_request_execution import ActionServiceRequestExecution
from zitadel_client.models.action_service_response_execution import ActionServiceResponseExecution
from zitadel_client.models.action_service_set_execution_request import ActionServiceSetExecutionRequest
from zitadel_client.models.action_service_set_execution_response import ActionServiceSetExecutionResponse
from zitadel_client.models.action_service_target import ActionServiceTarget
from zitadel_client.models.action_service_target_field_name import ActionServiceTargetFieldName
from zitadel_client.models.action_service_target_filter import ActionServiceTargetFilter
from zitadel_client.models.action_service_target_name_filter import ActionServiceTargetNameFilter
from zitadel_client.models.action_service_target_search_filter import ActionServiceTargetSearchFilter
from zitadel_client.models.action_service_text_filter_method import ActionServiceTextFilterMethod
from zitadel_client.models.action_service_update_target_request import ActionServiceUpdateTargetRequest
from zitadel_client.models.action_service_update_target_response import ActionServiceUpdateTargetResponse
from zitadel_client.models.beta_action_service_any import BetaActionServiceAny
from zitadel_client.models.beta_action_service_condition import BetaActionServiceCondition
from zitadel_client.models.beta_action_service_connect_error import BetaActionServiceConnectError
from zitadel_client.models.beta_action_service_create_target_request import BetaActionServiceCreateTargetRequest
from zitadel_client.models.beta_action_service_create_target_response import BetaActionServiceCreateTargetResponse
from zitadel_client.models.beta_action_service_delete_target_request import BetaActionServiceDeleteTargetRequest
from zitadel_client.models.beta_action_service_delete_target_response import BetaActionServiceDeleteTargetResponse
from zitadel_client.models.beta_action_service_event_execution import BetaActionServiceEventExecution
from zitadel_client.models.beta_action_service_execution import BetaActionServiceExecution
from zitadel_client.models.beta_action_service_execution_field_name import BetaActionServiceExecutionFieldName
from zitadel_client.models.beta_action_service_execution_search_filter import BetaActionServiceExecutionSearchFilter
from zitadel_client.models.beta_action_service_execution_type import BetaActionServiceExecutionType
from zitadel_client.models.beta_action_service_execution_type_filter import BetaActionServiceExecutionTypeFilter
from zitadel_client.models.beta_action_service_function_execution import BetaActionServiceFunctionExecution
from zitadel_client.models.beta_action_service_get_target_request import BetaActionServiceGetTargetRequest
from zitadel_client.models.beta_action_service_get_target_response import BetaActionServiceGetTargetResponse
from zitadel_client.models.beta_action_service_in_conditions_filter import BetaActionServiceInConditionsFilter
from zitadel_client.models.beta_action_service_in_target_ids_filter import BetaActionServiceInTargetIDsFilter
from zitadel_client.models.beta_action_service_list_execution_functions_response import BetaActionServiceListExecutionFunctionsResponse
from zitadel_client.models.beta_action_service_list_execution_methods_response import BetaActionServiceListExecutionMethodsResponse
from zitadel_client.models.beta_action_service_list_execution_services_response import BetaActionServiceListExecutionServicesResponse
from zitadel_client.models.beta_action_service_list_executions_request import BetaActionServiceListExecutionsRequest
from zitadel_client.models.beta_action_service_list_executions_response import BetaActionServiceListExecutionsResponse
from zitadel_client.models.beta_action_service_list_targets_request import BetaActionServiceListTargetsRequest
from zitadel_client.models.beta_action_service_list_targets_response import BetaActionServiceListTargetsResponse
from zitadel_client.models.beta_action_service_pagination_request import BetaActionServicePaginationRequest
from zitadel_client.models.beta_action_service_pagination_response import BetaActionServicePaginationResponse
from zitadel_client.models.beta_action_service_rest_call import BetaActionServiceRESTCall
from zitadel_client.models.beta_action_service_rest_webhook import BetaActionServiceRESTWebhook
from zitadel_client.models.beta_action_service_request_execution import BetaActionServiceRequestExecution
from zitadel_client.models.beta_action_service_response_execution import BetaActionServiceResponseExecution
from zitadel_client.models.beta_action_service_set_execution_request import BetaActionServiceSetExecutionRequest
from zitadel_client.models.beta_action_service_set_execution_response import BetaActionServiceSetExecutionResponse
from zitadel_client.models.beta_action_service_target import BetaActionServiceTarget
from zitadel_client.models.beta_action_service_target_field_name import BetaActionServiceTargetFieldName
from zitadel_client.models.beta_action_service_target_filter import BetaActionServiceTargetFilter
from zitadel_client.models.beta_action_service_target_name_filter import BetaActionServiceTargetNameFilter
from zitadel_client.models.beta_action_service_target_search_filter import BetaActionServiceTargetSearchFilter
from zitadel_client.models.beta_action_service_text_filter_method import BetaActionServiceTextFilterMethod
from zitadel_client.models.beta_action_service_update_target_request import BetaActionServiceUpdateTargetRequest
from zitadel_client.models.beta_action_service_update_target_response import BetaActionServiceUpdateTargetResponse
from zitadel_client.models.beta_app_service_api_auth_method_type import BetaAppServiceAPIAuthMethodType
from zitadel_client.models.beta_app_service_api_config import BetaAppServiceAPIConfig
from zitadel_client.models.beta_app_service_any import BetaAppServiceAny
from zitadel_client.models.beta_app_service_app_sorting import BetaAppServiceAppSorting
from zitadel_client.models.beta_app_service_app_state import BetaAppServiceAppState
from zitadel_client.models.beta_app_service_application import BetaAppServiceApplication
from zitadel_client.models.beta_app_service_application_key import BetaAppServiceApplicationKey
from zitadel_client.models.beta_app_service_application_keys_sorting import BetaAppServiceApplicationKeysSorting
from zitadel_client.models.beta_app_service_application_name_query import BetaAppServiceApplicationNameQuery
from zitadel_client.models.beta_app_service_application_search_filter import BetaAppServiceApplicationSearchFilter
from zitadel_client.models.beta_app_service_connect_error import BetaAppServiceConnectError
from zitadel_client.models.beta_app_service_create_api_application_request import BetaAppServiceCreateAPIApplicationRequest
from zitadel_client.models.beta_app_service_create_api_application_response import BetaAppServiceCreateAPIApplicationResponse
from zitadel_client.models.beta_app_service_create_application_key_request import BetaAppServiceCreateApplicationKeyRequest
from zitadel_client.models.beta_app_service_create_application_key_response import BetaAppServiceCreateApplicationKeyResponse
from zitadel_client.models.beta_app_service_create_application_request import BetaAppServiceCreateApplicationRequest
from zitadel_client.models.beta_app_service_create_application_response import BetaAppServiceCreateApplicationResponse
from zitadel_client.models.beta_app_service_create_oidc_application_request import BetaAppServiceCreateOIDCApplicationRequest
from zitadel_client.models.beta_app_service_create_oidc_application_response import BetaAppServiceCreateOIDCApplicationResponse
from zitadel_client.models.beta_app_service_create_saml_application_request import BetaAppServiceCreateSAMLApplicationRequest
from zitadel_client.models.beta_app_service_deactivate_application_request import BetaAppServiceDeactivateApplicationRequest
from zitadel_client.models.beta_app_service_deactivate_application_response import BetaAppServiceDeactivateApplicationResponse
from zitadel_client.models.beta_app_service_delete_application_key_request import BetaAppServiceDeleteApplicationKeyRequest
from zitadel_client.models.beta_app_service_delete_application_key_response import BetaAppServiceDeleteApplicationKeyResponse
from zitadel_client.models.beta_app_service_delete_application_request import BetaAppServiceDeleteApplicationRequest
from zitadel_client.models.beta_app_service_delete_application_response import BetaAppServiceDeleteApplicationResponse
from zitadel_client.models.beta_app_service_get_application_key_request import BetaAppServiceGetApplicationKeyRequest
from zitadel_client.models.beta_app_service_get_application_key_response import BetaAppServiceGetApplicationKeyResponse
from zitadel_client.models.beta_app_service_get_application_request import BetaAppServiceGetApplicationRequest
from zitadel_client.models.beta_app_service_get_application_response import BetaAppServiceGetApplicationResponse
from zitadel_client.models.beta_app_service_list_application_keys_request import BetaAppServiceListApplicationKeysRequest
from zitadel_client.models.beta_app_service_list_application_keys_response import BetaAppServiceListApplicationKeysResponse
from zitadel_client.models.beta_app_service_list_applications_request import BetaAppServiceListApplicationsRequest
from zitadel_client.models.beta_app_service_list_applications_response import BetaAppServiceListApplicationsResponse
from zitadel_client.models.beta_app_service_login_v2 import BetaAppServiceLoginV2
from zitadel_client.models.beta_app_service_login_version import BetaAppServiceLoginVersion
from zitadel_client.models.beta_app_service_oidc_app_type import BetaAppServiceOIDCAppType
from zitadel_client.models.beta_app_service_oidc_auth_method_type import BetaAppServiceOIDCAuthMethodType
from zitadel_client.models.beta_app_service_oidc_config import BetaAppServiceOIDCConfig
from zitadel_client.models.beta_app_service_oidc_grant_type import BetaAppServiceOIDCGrantType
from zitadel_client.models.beta_app_service_oidc_localized_message import BetaAppServiceOIDCLocalizedMessage
from zitadel_client.models.beta_app_service_oidc_response_type import BetaAppServiceOIDCResponseType
from zitadel_client.models.beta_app_service_oidc_token_type import BetaAppServiceOIDCTokenType
from zitadel_client.models.beta_app_service_oidc_version import BetaAppServiceOIDCVersion
from zitadel_client.models.beta_app_service_pagination_request import BetaAppServicePaginationRequest
from zitadel_client.models.beta_app_service_pagination_response import BetaAppServicePaginationResponse
from zitadel_client.models.beta_app_service_reactivate_application_request import BetaAppServiceReactivateApplicationRequest
from zitadel_client.models.beta_app_service_reactivate_application_response import BetaAppServiceReactivateApplicationResponse
from zitadel_client.models.beta_app_service_regenerate_client_secret_request import BetaAppServiceRegenerateClientSecretRequest
from zitadel_client.models.beta_app_service_regenerate_client_secret_response import BetaAppServiceRegenerateClientSecretResponse
from zitadel_client.models.beta_app_service_saml_config import BetaAppServiceSAMLConfig
from zitadel_client.models.beta_app_service_text_filter_method import BetaAppServiceTextFilterMethod
from zitadel_client.models.beta_app_service_update_api_application_configuration_request import BetaAppServiceUpdateAPIApplicationConfigurationRequest
from zitadel_client.models.beta_app_service_update_application_request import BetaAppServiceUpdateApplicationRequest
from zitadel_client.models.beta_app_service_update_application_response import BetaAppServiceUpdateApplicationResponse
from zitadel_client.models.beta_app_service_update_oidc_application_configuration_request import BetaAppServiceUpdateOIDCApplicationConfigurationRequest
from zitadel_client.models.beta_app_service_update_saml_application_configuration_request import BetaAppServiceUpdateSAMLApplicationConfigurationRequest
from zitadel_client.models.beta_authorization_service_activate_authorization_request import BetaAuthorizationServiceActivateAuthorizationRequest
from zitadel_client.models.beta_authorization_service_activate_authorization_response import BetaAuthorizationServiceActivateAuthorizationResponse
from zitadel_client.models.beta_authorization_service_any import BetaAuthorizationServiceAny
from zitadel_client.models.beta_authorization_service_authorization import BetaAuthorizationServiceAuthorization
from zitadel_client.models.beta_authorization_service_authorization_field_name import BetaAuthorizationServiceAuthorizationFieldName
from zitadel_client.models.beta_authorization_service_authorizations_search_filter import BetaAuthorizationServiceAuthorizationsSearchFilter
from zitadel_client.models.beta_authorization_service_connect_error import BetaAuthorizationServiceConnectError
from zitadel_client.models.beta_authorization_service_create_authorization_request import BetaAuthorizationServiceCreateAuthorizationRequest
from zitadel_client.models.beta_authorization_service_create_authorization_response import BetaAuthorizationServiceCreateAuthorizationResponse
from zitadel_client.models.beta_authorization_service_deactivate_authorization_request import BetaAuthorizationServiceDeactivateAuthorizationRequest
from zitadel_client.models.beta_authorization_service_deactivate_authorization_response import BetaAuthorizationServiceDeactivateAuthorizationResponse
from zitadel_client.models.beta_authorization_service_delete_authorization_request import BetaAuthorizationServiceDeleteAuthorizationRequest
from zitadel_client.models.beta_authorization_service_delete_authorization_response import BetaAuthorizationServiceDeleteAuthorizationResponse
from zitadel_client.models.beta_authorization_service_id_filter import BetaAuthorizationServiceIDFilter
from zitadel_client.models.beta_authorization_service_in_ids_filter import BetaAuthorizationServiceInIDsFilter
from zitadel_client.models.beta_authorization_service_list_authorizations_request import BetaAuthorizationServiceListAuthorizationsRequest
from zitadel_client.models.beta_authorization_service_list_authorizations_response import BetaAuthorizationServiceListAuthorizationsResponse
from zitadel_client.models.beta_authorization_service_pagination_request import BetaAuthorizationServicePaginationRequest
from zitadel_client.models.beta_authorization_service_pagination_response import BetaAuthorizationServicePaginationResponse
from zitadel_client.models.beta_authorization_service_project_name_query import BetaAuthorizationServiceProjectNameQuery
from zitadel_client.models.beta_authorization_service_role_key_query import BetaAuthorizationServiceRoleKeyQuery
from zitadel_client.models.beta_authorization_service_state import BetaAuthorizationServiceState
from zitadel_client.models.beta_authorization_service_state_query import BetaAuthorizationServiceStateQuery
from zitadel_client.models.beta_authorization_service_text_filter_method import BetaAuthorizationServiceTextFilterMethod
from zitadel_client.models.beta_authorization_service_update_authorization_request import BetaAuthorizationServiceUpdateAuthorizationRequest
from zitadel_client.models.beta_authorization_service_update_authorization_response import BetaAuthorizationServiceUpdateAuthorizationResponse
from zitadel_client.models.beta_authorization_service_user import BetaAuthorizationServiceUser
from zitadel_client.models.beta_authorization_service_user_display_name_query import BetaAuthorizationServiceUserDisplayNameQuery
from zitadel_client.models.beta_authorization_service_user_preferred_login_name_query import BetaAuthorizationServiceUserPreferredLoginNameQuery
from zitadel_client.models.beta_feature_service_any import BetaFeatureServiceAny
from zitadel_client.models.beta_feature_service_connect_error import BetaFeatureServiceConnectError
from zitadel_client.models.beta_feature_service_details import BetaFeatureServiceDetails
from zitadel_client.models.beta_feature_service_feature_flag import BetaFeatureServiceFeatureFlag
from zitadel_client.models.beta_feature_service_get_instance_features_request import BetaFeatureServiceGetInstanceFeaturesRequest
from zitadel_client.models.beta_feature_service_get_instance_features_response import BetaFeatureServiceGetInstanceFeaturesResponse
from zitadel_client.models.beta_feature_service_get_organization_features_request import BetaFeatureServiceGetOrganizationFeaturesRequest
from zitadel_client.models.beta_feature_service_get_organization_features_response import BetaFeatureServiceGetOrganizationFeaturesResponse
from zitadel_client.models.beta_feature_service_get_system_features_response import BetaFeatureServiceGetSystemFeaturesResponse
from zitadel_client.models.beta_feature_service_get_user_features_request import BetaFeatureServiceGetUserFeaturesRequest
from zitadel_client.models.beta_feature_service_get_user_features_response import BetaFeatureServiceGetUserFeaturesResponse
from zitadel_client.models.beta_feature_service_improved_performance import BetaFeatureServiceImprovedPerformance
from zitadel_client.models.beta_feature_service_improved_performance_feature_flag import BetaFeatureServiceImprovedPerformanceFeatureFlag
from zitadel_client.models.beta_feature_service_reset_instance_features_response import BetaFeatureServiceResetInstanceFeaturesResponse
from zitadel_client.models.beta_feature_service_reset_organization_features_request import BetaFeatureServiceResetOrganizationFeaturesRequest
from zitadel_client.models.beta_feature_service_reset_organization_features_response import BetaFeatureServiceResetOrganizationFeaturesResponse
from zitadel_client.models.beta_feature_service_reset_system_features_response import BetaFeatureServiceResetSystemFeaturesResponse
from zitadel_client.models.beta_feature_service_reset_user_features_request import BetaFeatureServiceResetUserFeaturesRequest
from zitadel_client.models.beta_feature_service_reset_user_features_response import BetaFeatureServiceResetUserFeaturesResponse
from zitadel_client.models.beta_feature_service_set_instance_features_request import BetaFeatureServiceSetInstanceFeaturesRequest
from zitadel_client.models.beta_feature_service_set_instance_features_response import BetaFeatureServiceSetInstanceFeaturesResponse
from zitadel_client.models.beta_feature_service_set_organization_features_request import BetaFeatureServiceSetOrganizationFeaturesRequest
from zitadel_client.models.beta_feature_service_set_organization_features_response import BetaFeatureServiceSetOrganizationFeaturesResponse
from zitadel_client.models.beta_feature_service_set_system_features_request import BetaFeatureServiceSetSystemFeaturesRequest
from zitadel_client.models.beta_feature_service_set_system_features_response import BetaFeatureServiceSetSystemFeaturesResponse
from zitadel_client.models.beta_feature_service_set_user_feature_request import BetaFeatureServiceSetUserFeatureRequest
from zitadel_client.models.beta_feature_service_set_user_features_response import BetaFeatureServiceSetUserFeaturesResponse
from zitadel_client.models.beta_feature_service_source import BetaFeatureServiceSource
from zitadel_client.models.beta_instance_service_add_custom_domain_request import BetaInstanceServiceAddCustomDomainRequest
from zitadel_client.models.beta_instance_service_add_custom_domain_response import BetaInstanceServiceAddCustomDomainResponse
from zitadel_client.models.beta_instance_service_add_trusted_domain_request import BetaInstanceServiceAddTrustedDomainRequest
from zitadel_client.models.beta_instance_service_add_trusted_domain_response import BetaInstanceServiceAddTrustedDomainResponse
from zitadel_client.models.beta_instance_service_any import BetaInstanceServiceAny
from zitadel_client.models.beta_instance_service_connect_error import BetaInstanceServiceConnectError
from zitadel_client.models.beta_instance_service_delete_instance_request import BetaInstanceServiceDeleteInstanceRequest
from zitadel_client.models.beta_instance_service_delete_instance_response import BetaInstanceServiceDeleteInstanceResponse
from zitadel_client.models.beta_instance_service_domain import BetaInstanceServiceDomain
from zitadel_client.models.beta_instance_service_domain_field_name import BetaInstanceServiceDomainFieldName
from zitadel_client.models.beta_instance_service_domain_generated_query import BetaInstanceServiceDomainGeneratedQuery
from zitadel_client.models.beta_instance_service_domain_primary_query import BetaInstanceServiceDomainPrimaryQuery
from zitadel_client.models.beta_instance_service_domain_query import BetaInstanceServiceDomainQuery
from zitadel_client.models.beta_instance_service_domain_search_query import BetaInstanceServiceDomainSearchQuery
from zitadel_client.models.beta_instance_service_domains_query import BetaInstanceServiceDomainsQuery
from zitadel_client.models.beta_instance_service_field_name import BetaInstanceServiceFieldName
from zitadel_client.models.beta_instance_service_get_instance_request import BetaInstanceServiceGetInstanceRequest
from zitadel_client.models.beta_instance_service_get_instance_response import BetaInstanceServiceGetInstanceResponse
from zitadel_client.models.beta_instance_service_ids_query import BetaInstanceServiceIdsQuery
from zitadel_client.models.beta_instance_service_instance import BetaInstanceServiceInstance
from zitadel_client.models.beta_instance_service_list_custom_domains_request import BetaInstanceServiceListCustomDomainsRequest
from zitadel_client.models.beta_instance_service_list_custom_domains_response import BetaInstanceServiceListCustomDomainsResponse
from zitadel_client.models.beta_instance_service_list_instances_request import BetaInstanceServiceListInstancesRequest
from zitadel_client.models.beta_instance_service_list_instances_response import BetaInstanceServiceListInstancesResponse
from zitadel_client.models.beta_instance_service_list_trusted_domains_request import BetaInstanceServiceListTrustedDomainsRequest
from zitadel_client.models.beta_instance_service_list_trusted_domains_response import BetaInstanceServiceListTrustedDomainsResponse
from zitadel_client.models.beta_instance_service_pagination_request import BetaInstanceServicePaginationRequest
from zitadel_client.models.beta_instance_service_pagination_response import BetaInstanceServicePaginationResponse
from zitadel_client.models.beta_instance_service_query import BetaInstanceServiceQuery
from zitadel_client.models.beta_instance_service_remove_custom_domain_request import BetaInstanceServiceRemoveCustomDomainRequest
from zitadel_client.models.beta_instance_service_remove_custom_domain_response import BetaInstanceServiceRemoveCustomDomainResponse
from zitadel_client.models.beta_instance_service_remove_trusted_domain_request import BetaInstanceServiceRemoveTrustedDomainRequest
from zitadel_client.models.beta_instance_service_remove_trusted_domain_response import BetaInstanceServiceRemoveTrustedDomainResponse
from zitadel_client.models.beta_instance_service_state import BetaInstanceServiceState
from zitadel_client.models.beta_instance_service_text_query_method import BetaInstanceServiceTextQueryMethod
from zitadel_client.models.beta_instance_service_trusted_domain import BetaInstanceServiceTrustedDomain
from zitadel_client.models.beta_instance_service_trusted_domain_field_name import BetaInstanceServiceTrustedDomainFieldName
from zitadel_client.models.beta_instance_service_trusted_domain_search_query import BetaInstanceServiceTrustedDomainSearchQuery
from zitadel_client.models.beta_instance_service_update_instance_request import BetaInstanceServiceUpdateInstanceRequest
from zitadel_client.models.beta_instance_service_update_instance_response import BetaInstanceServiceUpdateInstanceResponse
from zitadel_client.models.beta_internal_permission_service_administrator import BetaInternalPermissionServiceAdministrator
from zitadel_client.models.beta_internal_permission_service_administrator_field_name import BetaInternalPermissionServiceAdministratorFieldName
from zitadel_client.models.beta_internal_permission_service_administrator_search_filter import BetaInternalPermissionServiceAdministratorSearchFilter
from zitadel_client.models.beta_internal_permission_service_and_filter import BetaInternalPermissionServiceAndFilter
from zitadel_client.models.beta_internal_permission_service_any import BetaInternalPermissionServiceAny
from zitadel_client.models.beta_internal_permission_service_connect_error import BetaInternalPermissionServiceConnectError
from zitadel_client.models.beta_internal_permission_service_create_administrator_request import BetaInternalPermissionServiceCreateAdministratorRequest
from zitadel_client.models.beta_internal_permission_service_create_administrator_response import BetaInternalPermissionServiceCreateAdministratorResponse
from zitadel_client.models.beta_internal_permission_service_delete_administrator_request import BetaInternalPermissionServiceDeleteAdministratorRequest
from zitadel_client.models.beta_internal_permission_service_delete_administrator_response import BetaInternalPermissionServiceDeleteAdministratorResponse
from zitadel_client.models.beta_internal_permission_service_id_filter import BetaInternalPermissionServiceIDFilter
from zitadel_client.models.beta_internal_permission_service_in_ids_filter import BetaInternalPermissionServiceInIDsFilter
from zitadel_client.models.beta_internal_permission_service_list_administrators_request import BetaInternalPermissionServiceListAdministratorsRequest
from zitadel_client.models.beta_internal_permission_service_list_administrators_response import BetaInternalPermissionServiceListAdministratorsResponse
from zitadel_client.models.beta_internal_permission_service_not_filter import BetaInternalPermissionServiceNotFilter
from zitadel_client.models.beta_internal_permission_service_or_filter import BetaInternalPermissionServiceOrFilter
from zitadel_client.models.beta_internal_permission_service_organization import BetaInternalPermissionServiceOrganization
from zitadel_client.models.beta_internal_permission_service_pagination_request import BetaInternalPermissionServicePaginationRequest
from zitadel_client.models.beta_internal_permission_service_pagination_response import BetaInternalPermissionServicePaginationResponse
from zitadel_client.models.beta_internal_permission_service_project import BetaInternalPermissionServiceProject
from zitadel_client.models.beta_internal_permission_service_project_grant import BetaInternalPermissionServiceProjectGrant
from zitadel_client.models.beta_internal_permission_service_resource_filter import BetaInternalPermissionServiceResourceFilter
from zitadel_client.models.beta_internal_permission_service_resource_type import BetaInternalPermissionServiceResourceType
from zitadel_client.models.beta_internal_permission_service_role_filter import BetaInternalPermissionServiceRoleFilter
from zitadel_client.models.beta_internal_permission_service_text_filter_method import BetaInternalPermissionServiceTextFilterMethod
from zitadel_client.models.beta_internal_permission_service_timestamp_filter import BetaInternalPermissionServiceTimestampFilter
from zitadel_client.models.beta_internal_permission_service_timestamp_filter_method import BetaInternalPermissionServiceTimestampFilterMethod
from zitadel_client.models.beta_internal_permission_service_update_administrator_request import BetaInternalPermissionServiceUpdateAdministratorRequest
from zitadel_client.models.beta_internal_permission_service_update_administrator_response import BetaInternalPermissionServiceUpdateAdministratorResponse
from zitadel_client.models.beta_internal_permission_service_user import BetaInternalPermissionServiceUser
from zitadel_client.models.beta_internal_permission_service_user_display_name_filter import BetaInternalPermissionServiceUserDisplayNameFilter
from zitadel_client.models.beta_internal_permission_service_user_preferred_login_name_filter import BetaInternalPermissionServiceUserPreferredLoginNameFilter
from zitadel_client.models.beta_oidc_service_any import BetaOIDCServiceAny
from zitadel_client.models.beta_oidc_service_auth_request import BetaOIDCServiceAuthRequest
from zitadel_client.models.beta_oidc_service_authorization_error import BetaOIDCServiceAuthorizationError
from zitadel_client.models.beta_oidc_service_connect_error import BetaOIDCServiceConnectError
from zitadel_client.models.beta_oidc_service_create_callback_request import BetaOIDCServiceCreateCallbackRequest
from zitadel_client.models.beta_oidc_service_create_callback_response import BetaOIDCServiceCreateCallbackResponse
from zitadel_client.models.beta_oidc_service_details import BetaOIDCServiceDetails
from zitadel_client.models.beta_oidc_service_error_reason import BetaOIDCServiceErrorReason
from zitadel_client.models.beta_oidc_service_get_auth_request_request import BetaOIDCServiceGetAuthRequestRequest
from zitadel_client.models.beta_oidc_service_get_auth_request_response import BetaOIDCServiceGetAuthRequestResponse
from zitadel_client.models.beta_oidc_service_prompt import BetaOIDCServicePrompt
from zitadel_client.models.beta_oidc_service_session import BetaOIDCServiceSession
from zitadel_client.models.beta_organization_service_activate_organization_request import BetaOrganizationServiceActivateOrganizationRequest
from zitadel_client.models.beta_organization_service_activate_organization_response import BetaOrganizationServiceActivateOrganizationResponse
from zitadel_client.models.beta_organization_service_add_human_user_request import BetaOrganizationServiceAddHumanUserRequest
from zitadel_client.models.beta_organization_service_add_organization_domain_request import BetaOrganizationServiceAddOrganizationDomainRequest
from zitadel_client.models.beta_organization_service_add_organization_domain_response import BetaOrganizationServiceAddOrganizationDomainResponse
from zitadel_client.models.beta_organization_service_admin import BetaOrganizationServiceAdmin
from zitadel_client.models.beta_organization_service_any import BetaOrganizationServiceAny
from zitadel_client.models.beta_organization_service_assigned_admin import BetaOrganizationServiceAssignedAdmin
from zitadel_client.models.beta_organization_service_connect_error import BetaOrganizationServiceConnectError
from zitadel_client.models.beta_organization_service_create_organization_request import BetaOrganizationServiceCreateOrganizationRequest
from zitadel_client.models.beta_organization_service_create_organization_response import BetaOrganizationServiceCreateOrganizationResponse
from zitadel_client.models.beta_organization_service_created_admin import BetaOrganizationServiceCreatedAdmin
from zitadel_client.models.beta_organization_service_deactivate_organization_request import BetaOrganizationServiceDeactivateOrganizationRequest
from zitadel_client.models.beta_organization_service_deactivate_organization_response import BetaOrganizationServiceDeactivateOrganizationResponse
from zitadel_client.models.beta_organization_service_delete_organization_domain_request import BetaOrganizationServiceDeleteOrganizationDomainRequest
from zitadel_client.models.beta_organization_service_delete_organization_domain_response import BetaOrganizationServiceDeleteOrganizationDomainResponse
from zitadel_client.models.beta_organization_service_delete_organization_metadata_request import BetaOrganizationServiceDeleteOrganizationMetadataRequest
from zitadel_client.models.beta_organization_service_delete_organization_metadata_response import BetaOrganizationServiceDeleteOrganizationMetadataResponse
from zitadel_client.models.beta_organization_service_delete_organization_request import BetaOrganizationServiceDeleteOrganizationRequest
from zitadel_client.models.beta_organization_service_delete_organization_response import BetaOrganizationServiceDeleteOrganizationResponse
from zitadel_client.models.beta_organization_service_domain import BetaOrganizationServiceDomain
from zitadel_client.models.beta_organization_service_domain_name_filter import BetaOrganizationServiceDomainNameFilter
from zitadel_client.models.beta_organization_service_domain_search_filter import BetaOrganizationServiceDomainSearchFilter
from zitadel_client.models.beta_organization_service_domain_validation_type import BetaOrganizationServiceDomainValidationType
from zitadel_client.models.beta_organization_service_gender import BetaOrganizationServiceGender
from zitadel_client.models.beta_organization_service_generate_organization_domain_validation_request import BetaOrganizationServiceGenerateOrganizationDomainValidationRequest
from zitadel_client.models.beta_organization_service_generate_organization_domain_validation_response import BetaOrganizationServiceGenerateOrganizationDomainValidationResponse
from zitadel_client.models.beta_organization_service_hashed_password import BetaOrganizationServiceHashedPassword
from zitadel_client.models.beta_organization_service_idp_link import BetaOrganizationServiceIDPLink
from zitadel_client.models.beta_organization_service_list_organization_domains_request import BetaOrganizationServiceListOrganizationDomainsRequest
from zitadel_client.models.beta_organization_service_list_organization_domains_response import BetaOrganizationServiceListOrganizationDomainsResponse
from zitadel_client.models.beta_organization_service_list_organization_metadata_request import BetaOrganizationServiceListOrganizationMetadataRequest
from zitadel_client.models.beta_organization_service_list_organization_metadata_response import BetaOrganizationServiceListOrganizationMetadataResponse
from zitadel_client.models.beta_organization_service_list_organizations_request import BetaOrganizationServiceListOrganizationsRequest
from zitadel_client.models.beta_organization_service_list_organizations_response import BetaOrganizationServiceListOrganizationsResponse
from zitadel_client.models.beta_organization_service_metadata import BetaOrganizationServiceMetadata
from zitadel_client.models.beta_organization_service_metadata_key_query import BetaOrganizationServiceMetadataKeyQuery
from zitadel_client.models.beta_organization_service_metadata_query import BetaOrganizationServiceMetadataQuery
from zitadel_client.models.beta_organization_service_org_domain_filter import BetaOrganizationServiceOrgDomainFilter
from zitadel_client.models.beta_organization_service_org_field_name import BetaOrganizationServiceOrgFieldName
from zitadel_client.models.beta_organization_service_org_id_filter import BetaOrganizationServiceOrgIDFilter
from zitadel_client.models.beta_organization_service_org_name_filter import BetaOrganizationServiceOrgNameFilter
from zitadel_client.models.beta_organization_service_org_state import BetaOrganizationServiceOrgState
from zitadel_client.models.beta_organization_service_org_state_filter import BetaOrganizationServiceOrgStateFilter
from zitadel_client.models.beta_organization_service_organization import BetaOrganizationServiceOrganization
from zitadel_client.models.beta_organization_service_organization_admin import BetaOrganizationServiceOrganizationAdmin
from zitadel_client.models.beta_organization_service_organization_search_filter import BetaOrganizationServiceOrganizationSearchFilter
from zitadel_client.models.beta_organization_service_pagination_request import BetaOrganizationServicePaginationRequest
from zitadel_client.models.beta_organization_service_pagination_response import BetaOrganizationServicePaginationResponse
from zitadel_client.models.beta_organization_service_password import BetaOrganizationServicePassword
from zitadel_client.models.beta_organization_service_send_email_verification_code import BetaOrganizationServiceSendEmailVerificationCode
from zitadel_client.models.beta_organization_service_set_human_email import BetaOrganizationServiceSetHumanEmail
from zitadel_client.models.beta_organization_service_set_human_phone import BetaOrganizationServiceSetHumanPhone
from zitadel_client.models.beta_organization_service_set_human_profile import BetaOrganizationServiceSetHumanProfile
from zitadel_client.models.beta_organization_service_set_metadata_entry import BetaOrganizationServiceSetMetadataEntry
from zitadel_client.models.beta_organization_service_set_organization_metadata_request import BetaOrganizationServiceSetOrganizationMetadataRequest
from zitadel_client.models.beta_organization_service_set_organization_metadata_response import BetaOrganizationServiceSetOrganizationMetadataResponse
from zitadel_client.models.beta_organization_service_text_query_method import BetaOrganizationServiceTextQueryMethod
from zitadel_client.models.beta_organization_service_update_organization_request import BetaOrganizationServiceUpdateOrganizationRequest
from zitadel_client.models.beta_organization_service_update_organization_response import BetaOrganizationServiceUpdateOrganizationResponse
from zitadel_client.models.beta_organization_service_verify_organization_domain_request import BetaOrganizationServiceVerifyOrganizationDomainRequest
from zitadel_client.models.beta_organization_service_verify_organization_domain_response import BetaOrganizationServiceVerifyOrganizationDomainResponse
from zitadel_client.models.beta_project_service_activate_project_grant_request import BetaProjectServiceActivateProjectGrantRequest
from zitadel_client.models.beta_project_service_activate_project_grant_response import BetaProjectServiceActivateProjectGrantResponse
from zitadel_client.models.beta_project_service_activate_project_request import BetaProjectServiceActivateProjectRequest
from zitadel_client.models.beta_project_service_activate_project_response import BetaProjectServiceActivateProjectResponse
from zitadel_client.models.beta_project_service_add_project_role_request import BetaProjectServiceAddProjectRoleRequest
from zitadel_client.models.beta_project_service_add_project_role_response import BetaProjectServiceAddProjectRoleResponse
from zitadel_client.models.beta_project_service_admin import BetaProjectServiceAdmin
from zitadel_client.models.beta_project_service_any import BetaProjectServiceAny
from zitadel_client.models.beta_project_service_connect_error import BetaProjectServiceConnectError
from zitadel_client.models.beta_project_service_create_project_grant_request import BetaProjectServiceCreateProjectGrantRequest
from zitadel_client.models.beta_project_service_create_project_grant_response import BetaProjectServiceCreateProjectGrantResponse
from zitadel_client.models.beta_project_service_create_project_request import BetaProjectServiceCreateProjectRequest
from zitadel_client.models.beta_project_service_create_project_response import BetaProjectServiceCreateProjectResponse
from zitadel_client.models.beta_project_service_deactivate_project_grant_request import BetaProjectServiceDeactivateProjectGrantRequest
from zitadel_client.models.beta_project_service_deactivate_project_grant_response import BetaProjectServiceDeactivateProjectGrantResponse
from zitadel_client.models.beta_project_service_deactivate_project_request import BetaProjectServiceDeactivateProjectRequest
from zitadel_client.models.beta_project_service_deactivate_project_response import BetaProjectServiceDeactivateProjectResponse
from zitadel_client.models.beta_project_service_delete_project_grant_request import BetaProjectServiceDeleteProjectGrantRequest
from zitadel_client.models.beta_project_service_delete_project_grant_response import BetaProjectServiceDeleteProjectGrantResponse
from zitadel_client.models.beta_project_service_delete_project_request import BetaProjectServiceDeleteProjectRequest
from zitadel_client.models.beta_project_service_delete_project_response import BetaProjectServiceDeleteProjectResponse
from zitadel_client.models.beta_project_service_get_project_request import BetaProjectServiceGetProjectRequest
from zitadel_client.models.beta_project_service_get_project_response import BetaProjectServiceGetProjectResponse
from zitadel_client.models.beta_project_service_granted_project_state import BetaProjectServiceGrantedProjectState
from zitadel_client.models.beta_project_service_id_filter import BetaProjectServiceIDFilter
from zitadel_client.models.beta_project_service_in_ids_filter import BetaProjectServiceInIDsFilter
from zitadel_client.models.beta_project_service_list_project_grants_request import BetaProjectServiceListProjectGrantsRequest
from zitadel_client.models.beta_project_service_list_project_grants_response import BetaProjectServiceListProjectGrantsResponse
from zitadel_client.models.beta_project_service_list_project_roles_request import BetaProjectServiceListProjectRolesRequest
from zitadel_client.models.beta_project_service_list_project_roles_response import BetaProjectServiceListProjectRolesResponse
from zitadel_client.models.beta_project_service_list_projects_request import BetaProjectServiceListProjectsRequest
from zitadel_client.models.beta_project_service_list_projects_response import BetaProjectServiceListProjectsResponse
from zitadel_client.models.beta_project_service_pagination_request import BetaProjectServicePaginationRequest
from zitadel_client.models.beta_project_service_pagination_response import BetaProjectServicePaginationResponse
from zitadel_client.models.beta_project_service_private_labeling_setting import BetaProjectServicePrivateLabelingSetting
from zitadel_client.models.beta_project_service_project import BetaProjectServiceProject
from zitadel_client.models.beta_project_service_project_field_name import BetaProjectServiceProjectFieldName
from zitadel_client.models.beta_project_service_project_grant import BetaProjectServiceProjectGrant
from zitadel_client.models.beta_project_service_project_grant_field_name import BetaProjectServiceProjectGrantFieldName
from zitadel_client.models.beta_project_service_project_grant_search_filter import BetaProjectServiceProjectGrantSearchFilter
from zitadel_client.models.beta_project_service_project_grant_state import BetaProjectServiceProjectGrantState
from zitadel_client.models.beta_project_service_project_name_filter import BetaProjectServiceProjectNameFilter
from zitadel_client.models.beta_project_service_project_role import BetaProjectServiceProjectRole
from zitadel_client.models.beta_project_service_project_role_display_name_filter import BetaProjectServiceProjectRoleDisplayNameFilter
from zitadel_client.models.beta_project_service_project_role_field_name import BetaProjectServiceProjectRoleFieldName
from zitadel_client.models.beta_project_service_project_role_key_filter import BetaProjectServiceProjectRoleKeyFilter
from zitadel_client.models.beta_project_service_project_role_search_filter import BetaProjectServiceProjectRoleSearchFilter
from zitadel_client.models.beta_project_service_project_search_filter import BetaProjectServiceProjectSearchFilter
from zitadel_client.models.beta_project_service_project_state import BetaProjectServiceProjectState
from zitadel_client.models.beta_project_service_remove_project_role_request import BetaProjectServiceRemoveProjectRoleRequest
from zitadel_client.models.beta_project_service_remove_project_role_response import BetaProjectServiceRemoveProjectRoleResponse
from zitadel_client.models.beta_project_service_text_filter_method import BetaProjectServiceTextFilterMethod
from zitadel_client.models.beta_project_service_update_project_grant_request import BetaProjectServiceUpdateProjectGrantRequest
from zitadel_client.models.beta_project_service_update_project_grant_response import BetaProjectServiceUpdateProjectGrantResponse
from zitadel_client.models.beta_project_service_update_project_request import BetaProjectServiceUpdateProjectRequest
from zitadel_client.models.beta_project_service_update_project_response import BetaProjectServiceUpdateProjectResponse
from zitadel_client.models.beta_project_service_update_project_role_request import BetaProjectServiceUpdateProjectRoleRequest
from zitadel_client.models.beta_project_service_update_project_role_response import BetaProjectServiceUpdateProjectRoleResponse
from zitadel_client.models.beta_session_service_any import BetaSessionServiceAny
from zitadel_client.models.beta_session_service_challenges import BetaSessionServiceChallenges
from zitadel_client.models.beta_session_service_check_idp_intent import BetaSessionServiceCheckIDPIntent
from zitadel_client.models.beta_session_service_check_otp import BetaSessionServiceCheckOTP
from zitadel_client.models.beta_session_service_check_password import BetaSessionServiceCheckPassword
from zitadel_client.models.beta_session_service_check_totp import BetaSessionServiceCheckTOTP
from zitadel_client.models.beta_session_service_check_user import BetaSessionServiceCheckUser
from zitadel_client.models.beta_session_service_check_web_auth_n import BetaSessionServiceCheckWebAuthN
from zitadel_client.models.beta_session_service_checks import BetaSessionServiceChecks
from zitadel_client.models.beta_session_service_connect_error import BetaSessionServiceConnectError
from zitadel_client.models.beta_session_service_create_session_request import BetaSessionServiceCreateSessionRequest
from zitadel_client.models.beta_session_service_create_session_response import BetaSessionServiceCreateSessionResponse
from zitadel_client.models.beta_session_service_creation_date_query import BetaSessionServiceCreationDateQuery
from zitadel_client.models.beta_session_service_delete_session_request import BetaSessionServiceDeleteSessionRequest
from zitadel_client.models.beta_session_service_delete_session_response import BetaSessionServiceDeleteSessionResponse
from zitadel_client.models.beta_session_service_details import BetaSessionServiceDetails
from zitadel_client.models.beta_session_service_factors import BetaSessionServiceFactors
from zitadel_client.models.beta_session_service_get_session_request import BetaSessionServiceGetSessionRequest
from zitadel_client.models.beta_session_service_get_session_response import BetaSessionServiceGetSessionResponse
from zitadel_client.models.beta_session_service_header_values import BetaSessionServiceHeaderValues
from zitadel_client.models.beta_session_service_ids_query import BetaSessionServiceIDsQuery
from zitadel_client.models.beta_session_service_intent_factor import BetaSessionServiceIntentFactor
from zitadel_client.models.beta_session_service_list_details import BetaSessionServiceListDetails
from zitadel_client.models.beta_session_service_list_query import BetaSessionServiceListQuery
from zitadel_client.models.beta_session_service_list_sessions_request import BetaSessionServiceListSessionsRequest
from zitadel_client.models.beta_session_service_list_sessions_response import BetaSessionServiceListSessionsResponse
from zitadel_client.models.beta_session_service_otp_email import BetaSessionServiceOTPEmail
from zitadel_client.models.beta_session_service_otp_factor import BetaSessionServiceOTPFactor
from zitadel_client.models.beta_session_service_otpsms import BetaSessionServiceOTPSMS
from zitadel_client.models.beta_session_service_password_factor import BetaSessionServicePasswordFactor
from zitadel_client.models.beta_session_service_request_challenges import BetaSessionServiceRequestChallenges
from zitadel_client.models.beta_session_service_search_query import BetaSessionServiceSearchQuery
from zitadel_client.models.beta_session_service_send_code import BetaSessionServiceSendCode
from zitadel_client.models.beta_session_service_session import BetaSessionServiceSession
from zitadel_client.models.beta_session_service_session_field_name import BetaSessionServiceSessionFieldName
from zitadel_client.models.beta_session_service_set_session_request import BetaSessionServiceSetSessionRequest
from zitadel_client.models.beta_session_service_set_session_response import BetaSessionServiceSetSessionResponse
from zitadel_client.models.beta_session_service_totp_factor import BetaSessionServiceTOTPFactor
from zitadel_client.models.beta_session_service_timestamp_query_method import BetaSessionServiceTimestampQueryMethod
from zitadel_client.models.beta_session_service_user_agent import BetaSessionServiceUserAgent
from zitadel_client.models.beta_session_service_user_factor import BetaSessionServiceUserFactor
from zitadel_client.models.beta_session_service_user_id_query import BetaSessionServiceUserIDQuery
from zitadel_client.models.beta_session_service_user_verification_requirement import BetaSessionServiceUserVerificationRequirement
from zitadel_client.models.beta_session_service_web_auth_n import BetaSessionServiceWebAuthN
from zitadel_client.models.beta_session_service_web_auth_n_factor import BetaSessionServiceWebAuthNFactor
from zitadel_client.models.beta_settings_service_any import BetaSettingsServiceAny
from zitadel_client.models.beta_settings_service_branding_settings import BetaSettingsServiceBrandingSettings
from zitadel_client.models.beta_settings_service_connect_error import BetaSettingsServiceConnectError
from zitadel_client.models.beta_settings_service_details import BetaSettingsServiceDetails
from zitadel_client.models.beta_settings_service_domain_settings import BetaSettingsServiceDomainSettings
from zitadel_client.models.beta_settings_service_embedded_iframe_settings import BetaSettingsServiceEmbeddedIframeSettings
from zitadel_client.models.beta_settings_service_get_active_identity_providers_request import BetaSettingsServiceGetActiveIdentityProvidersRequest
from zitadel_client.models.beta_settings_service_get_active_identity_providers_response import BetaSettingsServiceGetActiveIdentityProvidersResponse
from zitadel_client.models.beta_settings_service_get_branding_settings_request import BetaSettingsServiceGetBrandingSettingsRequest
from zitadel_client.models.beta_settings_service_get_branding_settings_response import BetaSettingsServiceGetBrandingSettingsResponse
from zitadel_client.models.beta_settings_service_get_domain_settings_request import BetaSettingsServiceGetDomainSettingsRequest
from zitadel_client.models.beta_settings_service_get_domain_settings_response import BetaSettingsServiceGetDomainSettingsResponse
from zitadel_client.models.beta_settings_service_get_general_settings_response import BetaSettingsServiceGetGeneralSettingsResponse
from zitadel_client.models.beta_settings_service_get_legal_and_support_settings_request import BetaSettingsServiceGetLegalAndSupportSettingsRequest
from zitadel_client.models.beta_settings_service_get_legal_and_support_settings_response import BetaSettingsServiceGetLegalAndSupportSettingsResponse
from zitadel_client.models.beta_settings_service_get_lockout_settings_request import BetaSettingsServiceGetLockoutSettingsRequest
from zitadel_client.models.beta_settings_service_get_lockout_settings_response import BetaSettingsServiceGetLockoutSettingsResponse
from zitadel_client.models.beta_settings_service_get_login_settings_request import BetaSettingsServiceGetLoginSettingsRequest
from zitadel_client.models.beta_settings_service_get_login_settings_response import BetaSettingsServiceGetLoginSettingsResponse
from zitadel_client.models.beta_settings_service_get_password_complexity_settings_request import BetaSettingsServiceGetPasswordComplexitySettingsRequest
from zitadel_client.models.beta_settings_service_get_password_complexity_settings_response import BetaSettingsServiceGetPasswordComplexitySettingsResponse
from zitadel_client.models.beta_settings_service_get_password_expiry_settings_request import BetaSettingsServiceGetPasswordExpirySettingsRequest
from zitadel_client.models.beta_settings_service_get_password_expiry_settings_response import BetaSettingsServiceGetPasswordExpirySettingsResponse
from zitadel_client.models.beta_settings_service_get_security_settings_response import BetaSettingsServiceGetSecuritySettingsResponse
from zitadel_client.models.beta_settings_service_identity_provider import BetaSettingsServiceIdentityProvider
from zitadel_client.models.beta_settings_service_identity_provider_type import BetaSettingsServiceIdentityProviderType
from zitadel_client.models.beta_settings_service_legal_and_support_settings import BetaSettingsServiceLegalAndSupportSettings
from zitadel_client.models.beta_settings_service_list_details import BetaSettingsServiceListDetails
from zitadel_client.models.beta_settings_service_lockout_settings import BetaSettingsServiceLockoutSettings
from zitadel_client.models.beta_settings_service_login_settings import BetaSettingsServiceLoginSettings
from zitadel_client.models.beta_settings_service_multi_factor_type import BetaSettingsServiceMultiFactorType
from zitadel_client.models.beta_settings_service_passkeys_type import BetaSettingsServicePasskeysType
from zitadel_client.models.beta_settings_service_password_complexity_settings import BetaSettingsServicePasswordComplexitySettings
from zitadel_client.models.beta_settings_service_password_expiry_settings import BetaSettingsServicePasswordExpirySettings
from zitadel_client.models.beta_settings_service_request_context import BetaSettingsServiceRequestContext
from zitadel_client.models.beta_settings_service_resource_owner_type import BetaSettingsServiceResourceOwnerType
from zitadel_client.models.beta_settings_service_second_factor_type import BetaSettingsServiceSecondFactorType
from zitadel_client.models.beta_settings_service_security_settings import BetaSettingsServiceSecuritySettings
from zitadel_client.models.beta_settings_service_set_security_settings_request import BetaSettingsServiceSetSecuritySettingsRequest
from zitadel_client.models.beta_settings_service_set_security_settings_response import BetaSettingsServiceSetSecuritySettingsResponse
from zitadel_client.models.beta_settings_service_theme import BetaSettingsServiceTheme
from zitadel_client.models.beta_settings_service_theme_mode import BetaSettingsServiceThemeMode
from zitadel_client.models.beta_telemetry_service_any import BetaTelemetryServiceAny
from zitadel_client.models.beta_telemetry_service_connect_error import BetaTelemetryServiceConnectError
from zitadel_client.models.beta_telemetry_service_count_parent_type import BetaTelemetryServiceCountParentType
from zitadel_client.models.beta_telemetry_service_instance_information import BetaTelemetryServiceInstanceInformation
from zitadel_client.models.beta_telemetry_service_report_base_information_request import BetaTelemetryServiceReportBaseInformationRequest
from zitadel_client.models.beta_telemetry_service_report_base_information_response import BetaTelemetryServiceReportBaseInformationResponse
from zitadel_client.models.beta_telemetry_service_report_resource_counts_request import BetaTelemetryServiceReportResourceCountsRequest
from zitadel_client.models.beta_telemetry_service_report_resource_counts_response import BetaTelemetryServiceReportResourceCountsResponse
from zitadel_client.models.beta_telemetry_service_resource_count import BetaTelemetryServiceResourceCount
from zitadel_client.models.beta_user_service_access_token_type import BetaUserServiceAccessTokenType
from zitadel_client.models.beta_user_service_add_human_user_request import BetaUserServiceAddHumanUserRequest
from zitadel_client.models.beta_user_service_add_human_user_response import BetaUserServiceAddHumanUserResponse
from zitadel_client.models.beta_user_service_add_idp_link_request import BetaUserServiceAddIDPLinkRequest
from zitadel_client.models.beta_user_service_add_idp_link_response import BetaUserServiceAddIDPLinkResponse
from zitadel_client.models.beta_user_service_add_otp_email_request import BetaUserServiceAddOTPEmailRequest
from zitadel_client.models.beta_user_service_add_otp_email_response import BetaUserServiceAddOTPEmailResponse
from zitadel_client.models.beta_user_service_add_otpsms_request import BetaUserServiceAddOTPSMSRequest
from zitadel_client.models.beta_user_service_add_otpsms_response import BetaUserServiceAddOTPSMSResponse
from zitadel_client.models.beta_user_service_and_query import BetaUserServiceAndQuery
from zitadel_client.models.beta_user_service_any import BetaUserServiceAny
from zitadel_client.models.beta_user_service_authentication_method_type import BetaUserServiceAuthenticationMethodType
from zitadel_client.models.beta_user_service_connect_error import BetaUserServiceConnectError
from zitadel_client.models.beta_user_service_create_passkey_registration_link_request import BetaUserServiceCreatePasskeyRegistrationLinkRequest
from zitadel_client.models.beta_user_service_create_passkey_registration_link_response import BetaUserServiceCreatePasskeyRegistrationLinkResponse
from zitadel_client.models.beta_user_service_deactivate_user_request import BetaUserServiceDeactivateUserRequest
from zitadel_client.models.beta_user_service_deactivate_user_response import BetaUserServiceDeactivateUserResponse
from zitadel_client.models.beta_user_service_delete_user_request import BetaUserServiceDeleteUserRequest
from zitadel_client.models.beta_user_service_delete_user_response import BetaUserServiceDeleteUserResponse
from zitadel_client.models.beta_user_service_details import BetaUserServiceDetails
from zitadel_client.models.beta_user_service_display_name_query import BetaUserServiceDisplayNameQuery
from zitadel_client.models.beta_user_service_email_query import BetaUserServiceEmailQuery
from zitadel_client.models.beta_user_service_first_name_query import BetaUserServiceFirstNameQuery
from zitadel_client.models.beta_user_service_form_data import BetaUserServiceFormData
from zitadel_client.models.beta_user_service_gender import BetaUserServiceGender
from zitadel_client.models.beta_user_service_get_user_by_id_request import BetaUserServiceGetUserByIDRequest
from zitadel_client.models.beta_user_service_get_user_by_id_response import BetaUserServiceGetUserByIDResponse
from zitadel_client.models.beta_user_service_hashed_password import BetaUserServiceHashedPassword
from zitadel_client.models.beta_user_service_human_email import BetaUserServiceHumanEmail
from zitadel_client.models.beta_user_service_human_phone import BetaUserServiceHumanPhone
from zitadel_client.models.beta_user_service_human_profile import BetaUserServiceHumanProfile
from zitadel_client.models.beta_user_service_human_user import BetaUserServiceHumanUser
from zitadel_client.models.beta_user_service_idp_information import BetaUserServiceIDPInformation
from zitadel_client.models.beta_user_service_idp_intent import BetaUserServiceIDPIntent
from zitadel_client.models.beta_user_service_idpldap_access_information import BetaUserServiceIDPLDAPAccessInformation
from zitadel_client.models.beta_user_service_idp_link import BetaUserServiceIDPLink
from zitadel_client.models.beta_user_service_idpo_auth_access_information import BetaUserServiceIDPOAuthAccessInformation
from zitadel_client.models.beta_user_service_idpsaml_access_information import BetaUserServiceIDPSAMLAccessInformation
from zitadel_client.models.beta_user_service_in_user_emails_query import BetaUserServiceInUserEmailsQuery
from zitadel_client.models.beta_user_service_in_user_id_query import BetaUserServiceInUserIDQuery
from zitadel_client.models.beta_user_service_ldap_credentials import BetaUserServiceLDAPCredentials
from zitadel_client.models.beta_user_service_last_name_query import BetaUserServiceLastNameQuery
from zitadel_client.models.beta_user_service_list_authentication_method_types_request import BetaUserServiceListAuthenticationMethodTypesRequest
from zitadel_client.models.beta_user_service_list_authentication_method_types_response import BetaUserServiceListAuthenticationMethodTypesResponse
from zitadel_client.models.beta_user_service_list_details import BetaUserServiceListDetails
from zitadel_client.models.beta_user_service_list_query import BetaUserServiceListQuery
from zitadel_client.models.beta_user_service_list_users_request import BetaUserServiceListUsersRequest
from zitadel_client.models.beta_user_service_list_users_response import BetaUserServiceListUsersResponse
from zitadel_client.models.beta_user_service_lock_user_request import BetaUserServiceLockUserRequest
from zitadel_client.models.beta_user_service_lock_user_response import BetaUserServiceLockUserResponse
from zitadel_client.models.beta_user_service_login_name_query import BetaUserServiceLoginNameQuery
from zitadel_client.models.beta_user_service_machine_user import BetaUserServiceMachineUser
from zitadel_client.models.beta_user_service_nick_name_query import BetaUserServiceNickNameQuery
from zitadel_client.models.beta_user_service_not_query import BetaUserServiceNotQuery
from zitadel_client.models.beta_user_service_notification_type import BetaUserServiceNotificationType
from zitadel_client.models.beta_user_service_or_query import BetaUserServiceOrQuery
from zitadel_client.models.beta_user_service_organization import BetaUserServiceOrganization
from zitadel_client.models.beta_user_service_organization_id_query import BetaUserServiceOrganizationIdQuery
from zitadel_client.models.beta_user_service_passkey_authenticator import BetaUserServicePasskeyAuthenticator
from zitadel_client.models.beta_user_service_passkey_registration_code import BetaUserServicePasskeyRegistrationCode
from zitadel_client.models.beta_user_service_password import BetaUserServicePassword
from zitadel_client.models.beta_user_service_password_reset_request import BetaUserServicePasswordResetRequest
from zitadel_client.models.beta_user_service_password_reset_response import BetaUserServicePasswordResetResponse
from zitadel_client.models.beta_user_service_phone_query import BetaUserServicePhoneQuery
from zitadel_client.models.beta_user_service_reactivate_user_request import BetaUserServiceReactivateUserRequest
from zitadel_client.models.beta_user_service_reactivate_user_response import BetaUserServiceReactivateUserResponse
from zitadel_client.models.beta_user_service_redirect_urls import BetaUserServiceRedirectURLs
from zitadel_client.models.beta_user_service_register_passkey_request import BetaUserServiceRegisterPasskeyRequest
from zitadel_client.models.beta_user_service_register_passkey_response import BetaUserServiceRegisterPasskeyResponse
from zitadel_client.models.beta_user_service_register_totp_request import BetaUserServiceRegisterTOTPRequest
from zitadel_client.models.beta_user_service_register_totp_response import BetaUserServiceRegisterTOTPResponse
from zitadel_client.models.beta_user_service_register_u2_f_request import BetaUserServiceRegisterU2FRequest
from zitadel_client.models.beta_user_service_register_u2_f_response import BetaUserServiceRegisterU2FResponse
from zitadel_client.models.beta_user_service_remove_otp_email_request import BetaUserServiceRemoveOTPEmailRequest
from zitadel_client.models.beta_user_service_remove_otp_email_response import BetaUserServiceRemoveOTPEmailResponse
from zitadel_client.models.beta_user_service_remove_otpsms_request import BetaUserServiceRemoveOTPSMSRequest
from zitadel_client.models.beta_user_service_remove_otpsms_response import BetaUserServiceRemoveOTPSMSResponse
from zitadel_client.models.beta_user_service_remove_phone_request import BetaUserServiceRemovePhoneRequest
from zitadel_client.models.beta_user_service_remove_phone_response import BetaUserServiceRemovePhoneResponse
from zitadel_client.models.beta_user_service_remove_totp_request import BetaUserServiceRemoveTOTPRequest
from zitadel_client.models.beta_user_service_remove_totp_response import BetaUserServiceRemoveTOTPResponse
from zitadel_client.models.beta_user_service_resend_email_code_request import BetaUserServiceResendEmailCodeRequest
from zitadel_client.models.beta_user_service_resend_email_code_response import BetaUserServiceResendEmailCodeResponse
from zitadel_client.models.beta_user_service_resend_phone_code_request import BetaUserServiceResendPhoneCodeRequest
from zitadel_client.models.beta_user_service_resend_phone_code_response import BetaUserServiceResendPhoneCodeResponse
from zitadel_client.models.beta_user_service_retrieve_identity_provider_intent_request import BetaUserServiceRetrieveIdentityProviderIntentRequest
from zitadel_client.models.beta_user_service_retrieve_identity_provider_intent_response import BetaUserServiceRetrieveIdentityProviderIntentResponse
from zitadel_client.models.beta_user_service_search_query import BetaUserServiceSearchQuery
from zitadel_client.models.beta_user_service_send_email_verification_code import BetaUserServiceSendEmailVerificationCode
from zitadel_client.models.beta_user_service_send_passkey_registration_link import BetaUserServiceSendPasskeyRegistrationLink
from zitadel_client.models.beta_user_service_send_password_reset_link import BetaUserServiceSendPasswordResetLink
from zitadel_client.models.beta_user_service_set_email_request import BetaUserServiceSetEmailRequest
from zitadel_client.models.beta_user_service_set_email_response import BetaUserServiceSetEmailResponse
from zitadel_client.models.beta_user_service_set_human_email import BetaUserServiceSetHumanEmail
from zitadel_client.models.beta_user_service_set_human_phone import BetaUserServiceSetHumanPhone
from zitadel_client.models.beta_user_service_set_human_profile import BetaUserServiceSetHumanProfile
from zitadel_client.models.beta_user_service_set_metadata_entry import BetaUserServiceSetMetadataEntry
from zitadel_client.models.beta_user_service_set_password import BetaUserServiceSetPassword
from zitadel_client.models.beta_user_service_set_password_request import BetaUserServiceSetPasswordRequest
from zitadel_client.models.beta_user_service_set_password_response import BetaUserServiceSetPasswordResponse
from zitadel_client.models.beta_user_service_set_phone_request import BetaUserServiceSetPhoneRequest
from zitadel_client.models.beta_user_service_set_phone_response import BetaUserServiceSetPhoneResponse
from zitadel_client.models.beta_user_service_start_identity_provider_intent_request import BetaUserServiceStartIdentityProviderIntentRequest
from zitadel_client.models.beta_user_service_start_identity_provider_intent_response import BetaUserServiceStartIdentityProviderIntentResponse
from zitadel_client.models.beta_user_service_state_query import BetaUserServiceStateQuery
from zitadel_client.models.beta_user_service_text_query_method import BetaUserServiceTextQueryMethod
from zitadel_client.models.beta_user_service_type import BetaUserServiceType
from zitadel_client.models.beta_user_service_type_query import BetaUserServiceTypeQuery
from zitadel_client.models.beta_user_service_unlock_user_request import BetaUserServiceUnlockUserRequest
from zitadel_client.models.beta_user_service_unlock_user_response import BetaUserServiceUnlockUserResponse
from zitadel_client.models.beta_user_service_update_human_user_request import BetaUserServiceUpdateHumanUserRequest
from zitadel_client.models.beta_user_service_update_human_user_response import BetaUserServiceUpdateHumanUserResponse
from zitadel_client.models.beta_user_service_user import BetaUserServiceUser
from zitadel_client.models.beta_user_service_user_field_name import BetaUserServiceUserFieldName
from zitadel_client.models.beta_user_service_user_name_query import BetaUserServiceUserNameQuery
from zitadel_client.models.beta_user_service_user_state import BetaUserServiceUserState
from zitadel_client.models.beta_user_service_verify_email_request import BetaUserServiceVerifyEmailRequest
from zitadel_client.models.beta_user_service_verify_email_response import BetaUserServiceVerifyEmailResponse
from zitadel_client.models.beta_user_service_verify_passkey_registration_request import BetaUserServiceVerifyPasskeyRegistrationRequest
from zitadel_client.models.beta_user_service_verify_passkey_registration_response import BetaUserServiceVerifyPasskeyRegistrationResponse
from zitadel_client.models.beta_user_service_verify_phone_request import BetaUserServiceVerifyPhoneRequest
from zitadel_client.models.beta_user_service_verify_phone_response import BetaUserServiceVerifyPhoneResponse
from zitadel_client.models.beta_user_service_verify_totp_registration_request import BetaUserServiceVerifyTOTPRegistrationRequest
from zitadel_client.models.beta_user_service_verify_totp_registration_response import BetaUserServiceVerifyTOTPRegistrationResponse
from zitadel_client.models.beta_user_service_verify_u2_f_registration_request import BetaUserServiceVerifyU2FRegistrationRequest
from zitadel_client.models.beta_user_service_verify_u2_f_registration_response import BetaUserServiceVerifyU2FRegistrationResponse
from zitadel_client.models.beta_web_key_service_activate_web_key_request import BetaWebKeyServiceActivateWebKeyRequest
from zitadel_client.models.beta_web_key_service_activate_web_key_response import BetaWebKeyServiceActivateWebKeyResponse
from zitadel_client.models.beta_web_key_service_any import BetaWebKeyServiceAny
from zitadel_client.models.beta_web_key_service_connect_error import BetaWebKeyServiceConnectError
from zitadel_client.models.beta_web_key_service_create_web_key_request import BetaWebKeyServiceCreateWebKeyRequest
from zitadel_client.models.beta_web_key_service_create_web_key_response import BetaWebKeyServiceCreateWebKeyResponse
from zitadel_client.models.beta_web_key_service_delete_web_key_request import BetaWebKeyServiceDeleteWebKeyRequest
from zitadel_client.models.beta_web_key_service_delete_web_key_response import BetaWebKeyServiceDeleteWebKeyResponse
from zitadel_client.models.beta_web_key_service_ecdsa import BetaWebKeyServiceECDSA
from zitadel_client.models.beta_web_key_service_ecdsa_curve import BetaWebKeyServiceECDSACurve
from zitadel_client.models.beta_web_key_service_list_web_keys_response import BetaWebKeyServiceListWebKeysResponse
from zitadel_client.models.beta_web_key_service_rsa import BetaWebKeyServiceRSA
from zitadel_client.models.beta_web_key_service_rsa_bits import BetaWebKeyServiceRSABits
from zitadel_client.models.beta_web_key_service_rsa_hasher import BetaWebKeyServiceRSAHasher
from zitadel_client.models.beta_web_key_service_state import BetaWebKeyServiceState
from zitadel_client.models.beta_web_key_service_web_key import BetaWebKeyServiceWebKey
from zitadel_client.models.feature_service_any import FeatureServiceAny
from zitadel_client.models.feature_service_connect_error import FeatureServiceConnectError
from zitadel_client.models.feature_service_details import FeatureServiceDetails
from zitadel_client.models.feature_service_feature_flag import FeatureServiceFeatureFlag
from zitadel_client.models.feature_service_get_instance_features_request import FeatureServiceGetInstanceFeaturesRequest
from zitadel_client.models.feature_service_get_instance_features_response import FeatureServiceGetInstanceFeaturesResponse
from zitadel_client.models.feature_service_get_organization_features_request import FeatureServiceGetOrganizationFeaturesRequest
from zitadel_client.models.feature_service_get_organization_features_response import FeatureServiceGetOrganizationFeaturesResponse
from zitadel_client.models.feature_service_get_system_features_response import FeatureServiceGetSystemFeaturesResponse
from zitadel_client.models.feature_service_get_user_features_request import FeatureServiceGetUserFeaturesRequest
from zitadel_client.models.feature_service_get_user_features_response import FeatureServiceGetUserFeaturesResponse
from zitadel_client.models.feature_service_improved_performance import FeatureServiceImprovedPerformance
from zitadel_client.models.feature_service_improved_performance_feature_flag import FeatureServiceImprovedPerformanceFeatureFlag
from zitadel_client.models.feature_service_login_v2 import FeatureServiceLoginV2
from zitadel_client.models.feature_service_login_v2_feature_flag import FeatureServiceLoginV2FeatureFlag
from zitadel_client.models.feature_service_reset_instance_features_response import FeatureServiceResetInstanceFeaturesResponse
from zitadel_client.models.feature_service_reset_organization_features_request import FeatureServiceResetOrganizationFeaturesRequest
from zitadel_client.models.feature_service_reset_organization_features_response import FeatureServiceResetOrganizationFeaturesResponse
from zitadel_client.models.feature_service_reset_system_features_response import FeatureServiceResetSystemFeaturesResponse
from zitadel_client.models.feature_service_reset_user_features_request import FeatureServiceResetUserFeaturesRequest
from zitadel_client.models.feature_service_reset_user_features_response import FeatureServiceResetUserFeaturesResponse
from zitadel_client.models.feature_service_set_instance_features_request import FeatureServiceSetInstanceFeaturesRequest
from zitadel_client.models.feature_service_set_instance_features_response import FeatureServiceSetInstanceFeaturesResponse
from zitadel_client.models.feature_service_set_organization_features_request import FeatureServiceSetOrganizationFeaturesRequest
from zitadel_client.models.feature_service_set_organization_features_response import FeatureServiceSetOrganizationFeaturesResponse
from zitadel_client.models.feature_service_set_system_features_request import FeatureServiceSetSystemFeaturesRequest
from zitadel_client.models.feature_service_set_system_features_response import FeatureServiceSetSystemFeaturesResponse
from zitadel_client.models.feature_service_set_user_feature_request import FeatureServiceSetUserFeatureRequest
from zitadel_client.models.feature_service_set_user_features_response import FeatureServiceSetUserFeaturesResponse
from zitadel_client.models.feature_service_source import FeatureServiceSource
from zitadel_client.models.identity_provider_service_any import IdentityProviderServiceAny
from zitadel_client.models.identity_provider_service_apple_config import IdentityProviderServiceAppleConfig
from zitadel_client.models.identity_provider_service_auto_linking_option import IdentityProviderServiceAutoLinkingOption
from zitadel_client.models.identity_provider_service_azure_ad_config import IdentityProviderServiceAzureADConfig
from zitadel_client.models.identity_provider_service_azure_ad_tenant import IdentityProviderServiceAzureADTenant
from zitadel_client.models.identity_provider_service_azure_ad_tenant_type import IdentityProviderServiceAzureADTenantType
from zitadel_client.models.identity_provider_service_connect_error import IdentityProviderServiceConnectError
from zitadel_client.models.identity_provider_service_details import IdentityProviderServiceDetails
from zitadel_client.models.identity_provider_service_generic_oidc_config import IdentityProviderServiceGenericOIDCConfig
from zitadel_client.models.identity_provider_service_get_idpby_id_request import IdentityProviderServiceGetIDPByIDRequest
from zitadel_client.models.identity_provider_service_get_idpby_id_response import IdentityProviderServiceGetIDPByIDResponse
from zitadel_client.models.identity_provider_service_git_hub_config import IdentityProviderServiceGitHubConfig
from zitadel_client.models.identity_provider_service_git_hub_enterprise_server_config import IdentityProviderServiceGitHubEnterpriseServerConfig
from zitadel_client.models.identity_provider_service_git_lab_config import IdentityProviderServiceGitLabConfig
from zitadel_client.models.identity_provider_service_git_lab_self_hosted_config import IdentityProviderServiceGitLabSelfHostedConfig
from zitadel_client.models.identity_provider_service_google_config import IdentityProviderServiceGoogleConfig
from zitadel_client.models.identity_provider_service_idp import IdentityProviderServiceIDP
from zitadel_client.models.identity_provider_service_idp_config import IdentityProviderServiceIDPConfig
from zitadel_client.models.identity_provider_service_idp_state import IdentityProviderServiceIDPState
from zitadel_client.models.identity_provider_service_idp_type import IdentityProviderServiceIDPType
from zitadel_client.models.identity_provider_service_jwt_config import IdentityProviderServiceJWTConfig
from zitadel_client.models.identity_provider_service_ldap_attributes import IdentityProviderServiceLDAPAttributes
from zitadel_client.models.identity_provider_service_ldap_config import IdentityProviderServiceLDAPConfig
from zitadel_client.models.identity_provider_service_o_auth_config import IdentityProviderServiceOAuthConfig
from zitadel_client.models.identity_provider_service_options import IdentityProviderServiceOptions
from zitadel_client.models.identity_provider_service_saml_binding import IdentityProviderServiceSAMLBinding
from zitadel_client.models.identity_provider_service_saml_config import IdentityProviderServiceSAMLConfig
from zitadel_client.models.identity_provider_service_saml_name_id_format import IdentityProviderServiceSAMLNameIDFormat
from zitadel_client.models.identity_provider_service_saml_signature_algorithm import IdentityProviderServiceSAMLSignatureAlgorithm
from zitadel_client.models.oidc_service_any import OIDCServiceAny
from zitadel_client.models.oidc_service_auth_request import OIDCServiceAuthRequest
from zitadel_client.models.oidc_service_authorization_error import OIDCServiceAuthorizationError
from zitadel_client.models.oidc_service_authorize_or_deny_device_authorization_request import OIDCServiceAuthorizeOrDenyDeviceAuthorizationRequest
from zitadel_client.models.oidc_service_connect_error import OIDCServiceConnectError
from zitadel_client.models.oidc_service_create_callback_request import OIDCServiceCreateCallbackRequest
from zitadel_client.models.oidc_service_create_callback_response import OIDCServiceCreateCallbackResponse
from zitadel_client.models.oidc_service_details import OIDCServiceDetails
from zitadel_client.models.oidc_service_device_authorization_request import OIDCServiceDeviceAuthorizationRequest
from zitadel_client.models.oidc_service_error_reason import OIDCServiceErrorReason
from zitadel_client.models.oidc_service_get_auth_request_request import OIDCServiceGetAuthRequestRequest
from zitadel_client.models.oidc_service_get_auth_request_response import OIDCServiceGetAuthRequestResponse
from zitadel_client.models.oidc_service_get_device_authorization_request_request import OIDCServiceGetDeviceAuthorizationRequestRequest
from zitadel_client.models.oidc_service_get_device_authorization_request_response import OIDCServiceGetDeviceAuthorizationRequestResponse
from zitadel_client.models.oidc_service_prompt import OIDCServicePrompt
from zitadel_client.models.oidc_service_session import OIDCServiceSession
from zitadel_client.models.organization_service_add_human_user_request import OrganizationServiceAddHumanUserRequest
from zitadel_client.models.organization_service_add_organization_request import OrganizationServiceAddOrganizationRequest
from zitadel_client.models.organization_service_add_organization_response import OrganizationServiceAddOrganizationResponse
from zitadel_client.models.organization_service_admin import OrganizationServiceAdmin
from zitadel_client.models.organization_service_any import OrganizationServiceAny
from zitadel_client.models.organization_service_connect_error import OrganizationServiceConnectError
from zitadel_client.models.organization_service_created_admin import OrganizationServiceCreatedAdmin
from zitadel_client.models.organization_service_details import OrganizationServiceDetails
from zitadel_client.models.organization_service_gender import OrganizationServiceGender
from zitadel_client.models.organization_service_hashed_password import OrganizationServiceHashedPassword
from zitadel_client.models.organization_service_idp_link import OrganizationServiceIDPLink
from zitadel_client.models.organization_service_list_details import OrganizationServiceListDetails
from zitadel_client.models.organization_service_list_organizations_request import OrganizationServiceListOrganizationsRequest
from zitadel_client.models.organization_service_list_organizations_response import OrganizationServiceListOrganizationsResponse
from zitadel_client.models.organization_service_list_query import OrganizationServiceListQuery
from zitadel_client.models.organization_service_organization import OrganizationServiceOrganization
from zitadel_client.models.organization_service_organization_domain_query import OrganizationServiceOrganizationDomainQuery
from zitadel_client.models.organization_service_organization_field_name import OrganizationServiceOrganizationFieldName
from zitadel_client.models.organization_service_organization_id_query import OrganizationServiceOrganizationIDQuery
from zitadel_client.models.organization_service_organization_name_query import OrganizationServiceOrganizationNameQuery
from zitadel_client.models.organization_service_organization_state import OrganizationServiceOrganizationState
from zitadel_client.models.organization_service_organization_state_query import OrganizationServiceOrganizationStateQuery
from zitadel_client.models.organization_service_password import OrganizationServicePassword
from zitadel_client.models.organization_service_search_query import OrganizationServiceSearchQuery
from zitadel_client.models.organization_service_send_email_verification_code import OrganizationServiceSendEmailVerificationCode
from zitadel_client.models.organization_service_set_human_email import OrganizationServiceSetHumanEmail
from zitadel_client.models.organization_service_set_human_phone import OrganizationServiceSetHumanPhone
from zitadel_client.models.organization_service_set_human_profile import OrganizationServiceSetHumanProfile
from zitadel_client.models.organization_service_set_metadata_entry import OrganizationServiceSetMetadataEntry
from zitadel_client.models.organization_service_text_query_method import OrganizationServiceTextQueryMethod
from zitadel_client.models.saml_service_any import SAMLServiceAny
from zitadel_client.models.saml_service_authorization_error import SAMLServiceAuthorizationError
from zitadel_client.models.saml_service_connect_error import SAMLServiceConnectError
from zitadel_client.models.saml_service_create_response_request import SAMLServiceCreateResponseRequest
from zitadel_client.models.saml_service_create_response_response import SAMLServiceCreateResponseResponse
from zitadel_client.models.saml_service_details import SAMLServiceDetails
from zitadel_client.models.saml_service_error_reason import SAMLServiceErrorReason
from zitadel_client.models.saml_service_get_saml_request_request import SAMLServiceGetSAMLRequestRequest
from zitadel_client.models.saml_service_get_saml_request_response import SAMLServiceGetSAMLRequestResponse
from zitadel_client.models.saml_service_post_response import SAMLServicePostResponse
from zitadel_client.models.saml_service_saml_request import SAMLServiceSAMLRequest
from zitadel_client.models.saml_service_session import SAMLServiceSession
from zitadel_client.models.session_service_any import SessionServiceAny
from zitadel_client.models.session_service_challenges import SessionServiceChallenges
from zitadel_client.models.session_service_check_idp_intent import SessionServiceCheckIDPIntent
from zitadel_client.models.session_service_check_otp import SessionServiceCheckOTP
from zitadel_client.models.session_service_check_password import SessionServiceCheckPassword
from zitadel_client.models.session_service_check_totp import SessionServiceCheckTOTP
from zitadel_client.models.session_service_check_user import SessionServiceCheckUser
from zitadel_client.models.session_service_check_web_auth_n import SessionServiceCheckWebAuthN
from zitadel_client.models.session_service_checks import SessionServiceChecks
from zitadel_client.models.session_service_connect_error import SessionServiceConnectError
from zitadel_client.models.session_service_create_session_request import SessionServiceCreateSessionRequest
from zitadel_client.models.session_service_create_session_response import SessionServiceCreateSessionResponse
from zitadel_client.models.session_service_creation_date_query import SessionServiceCreationDateQuery
from zitadel_client.models.session_service_creator_query import SessionServiceCreatorQuery
from zitadel_client.models.session_service_delete_session_request import SessionServiceDeleteSessionRequest
from zitadel_client.models.session_service_delete_session_response import SessionServiceDeleteSessionResponse
from zitadel_client.models.session_service_details import SessionServiceDetails
from zitadel_client.models.session_service_expiration_date_query import SessionServiceExpirationDateQuery
from zitadel_client.models.session_service_factors import SessionServiceFactors
from zitadel_client.models.session_service_get_session_request import SessionServiceGetSessionRequest
from zitadel_client.models.session_service_get_session_response import SessionServiceGetSessionResponse
from zitadel_client.models.session_service_header_values import SessionServiceHeaderValues
from zitadel_client.models.session_service_ids_query import SessionServiceIDsQuery
from zitadel_client.models.session_service_intent_factor import SessionServiceIntentFactor
from zitadel_client.models.session_service_list_details import SessionServiceListDetails
from zitadel_client.models.session_service_list_query import SessionServiceListQuery
from zitadel_client.models.session_service_list_sessions_request import SessionServiceListSessionsRequest
from zitadel_client.models.session_service_list_sessions_response import SessionServiceListSessionsResponse
from zitadel_client.models.session_service_otp_email import SessionServiceOTPEmail
from zitadel_client.models.session_service_otp_factor import SessionServiceOTPFactor
from zitadel_client.models.session_service_otpsms import SessionServiceOTPSMS
from zitadel_client.models.session_service_password_factor import SessionServicePasswordFactor
from zitadel_client.models.session_service_request_challenges import SessionServiceRequestChallenges
from zitadel_client.models.session_service_search_query import SessionServiceSearchQuery
from zitadel_client.models.session_service_send_code import SessionServiceSendCode
from zitadel_client.models.session_service_session import SessionServiceSession
from zitadel_client.models.session_service_session_field_name import SessionServiceSessionFieldName
from zitadel_client.models.session_service_set_session_request import SessionServiceSetSessionRequest
from zitadel_client.models.session_service_set_session_response import SessionServiceSetSessionResponse
from zitadel_client.models.session_service_totp_factor import SessionServiceTOTPFactor
from zitadel_client.models.session_service_timestamp_query_method import SessionServiceTimestampQueryMethod
from zitadel_client.models.session_service_user_agent import SessionServiceUserAgent
from zitadel_client.models.session_service_user_agent_query import SessionServiceUserAgentQuery
from zitadel_client.models.session_service_user_factor import SessionServiceUserFactor
from zitadel_client.models.session_service_user_id_query import SessionServiceUserIDQuery
from zitadel_client.models.session_service_user_verification_requirement import SessionServiceUserVerificationRequirement
from zitadel_client.models.session_service_web_auth_n import SessionServiceWebAuthN
from zitadel_client.models.session_service_web_auth_n_factor import SessionServiceWebAuthNFactor
from zitadel_client.models.settings_service_any import SettingsServiceAny
from zitadel_client.models.settings_service_auto_linking_option import SettingsServiceAutoLinkingOption
from zitadel_client.models.settings_service_branding_settings import SettingsServiceBrandingSettings
from zitadel_client.models.settings_service_connect_error import SettingsServiceConnectError
from zitadel_client.models.settings_service_details import SettingsServiceDetails
from zitadel_client.models.settings_service_domain_settings import SettingsServiceDomainSettings
from zitadel_client.models.settings_service_embedded_iframe_settings import SettingsServiceEmbeddedIframeSettings
from zitadel_client.models.settings_service_get_active_identity_providers_request import SettingsServiceGetActiveIdentityProvidersRequest
from zitadel_client.models.settings_service_get_active_identity_providers_response import SettingsServiceGetActiveIdentityProvidersResponse
from zitadel_client.models.settings_service_get_branding_settings_request import SettingsServiceGetBrandingSettingsRequest
from zitadel_client.models.settings_service_get_branding_settings_response import SettingsServiceGetBrandingSettingsResponse
from zitadel_client.models.settings_service_get_domain_settings_request import SettingsServiceGetDomainSettingsRequest
from zitadel_client.models.settings_service_get_domain_settings_response import SettingsServiceGetDomainSettingsResponse
from zitadel_client.models.settings_service_get_general_settings_response import SettingsServiceGetGeneralSettingsResponse
from zitadel_client.models.settings_service_get_hosted_login_translation_request import SettingsServiceGetHostedLoginTranslationRequest
from zitadel_client.models.settings_service_get_hosted_login_translation_response import SettingsServiceGetHostedLoginTranslationResponse
from zitadel_client.models.settings_service_get_legal_and_support_settings_request import SettingsServiceGetLegalAndSupportSettingsRequest
from zitadel_client.models.settings_service_get_legal_and_support_settings_response import SettingsServiceGetLegalAndSupportSettingsResponse
from zitadel_client.models.settings_service_get_lockout_settings_request import SettingsServiceGetLockoutSettingsRequest
from zitadel_client.models.settings_service_get_lockout_settings_response import SettingsServiceGetLockoutSettingsResponse
from zitadel_client.models.settings_service_get_login_settings_request import SettingsServiceGetLoginSettingsRequest
from zitadel_client.models.settings_service_get_login_settings_response import SettingsServiceGetLoginSettingsResponse
from zitadel_client.models.settings_service_get_password_complexity_settings_request import SettingsServiceGetPasswordComplexitySettingsRequest
from zitadel_client.models.settings_service_get_password_complexity_settings_response import SettingsServiceGetPasswordComplexitySettingsResponse
from zitadel_client.models.settings_service_get_password_expiry_settings_request import SettingsServiceGetPasswordExpirySettingsRequest
from zitadel_client.models.settings_service_get_password_expiry_settings_response import SettingsServiceGetPasswordExpirySettingsResponse
from zitadel_client.models.settings_service_get_security_settings_response import SettingsServiceGetSecuritySettingsResponse
from zitadel_client.models.settings_service_identity_provider import SettingsServiceIdentityProvider
from zitadel_client.models.settings_service_identity_provider_type import SettingsServiceIdentityProviderType
from zitadel_client.models.settings_service_legal_and_support_settings import SettingsServiceLegalAndSupportSettings
from zitadel_client.models.settings_service_list_details import SettingsServiceListDetails
from zitadel_client.models.settings_service_lockout_settings import SettingsServiceLockoutSettings
from zitadel_client.models.settings_service_login_settings import SettingsServiceLoginSettings
from zitadel_client.models.settings_service_multi_factor_type import SettingsServiceMultiFactorType
from zitadel_client.models.settings_service_options import SettingsServiceOptions
from zitadel_client.models.settings_service_passkeys_type import SettingsServicePasskeysType
from zitadel_client.models.settings_service_password_complexity_settings import SettingsServicePasswordComplexitySettings
from zitadel_client.models.settings_service_password_expiry_settings import SettingsServicePasswordExpirySettings
from zitadel_client.models.settings_service_request_context import SettingsServiceRequestContext
from zitadel_client.models.settings_service_resource_owner_type import SettingsServiceResourceOwnerType
from zitadel_client.models.settings_service_second_factor_type import SettingsServiceSecondFactorType
from zitadel_client.models.settings_service_security_settings import SettingsServiceSecuritySettings
from zitadel_client.models.settings_service_set_hosted_login_translation_request import SettingsServiceSetHostedLoginTranslationRequest
from zitadel_client.models.settings_service_set_hosted_login_translation_response import SettingsServiceSetHostedLoginTranslationResponse
from zitadel_client.models.settings_service_set_security_settings_request import SettingsServiceSetSecuritySettingsRequest
from zitadel_client.models.settings_service_set_security_settings_response import SettingsServiceSetSecuritySettingsResponse
from zitadel_client.models.settings_service_theme import SettingsServiceTheme
from zitadel_client.models.settings_service_theme_mode import SettingsServiceThemeMode
from zitadel_client.models.user_service_access_token_type import UserServiceAccessTokenType
from zitadel_client.models.user_service_add_human_user_request import UserServiceAddHumanUserRequest
from zitadel_client.models.user_service_add_human_user_response import UserServiceAddHumanUserResponse
from zitadel_client.models.user_service_add_idp_link_request import UserServiceAddIDPLinkRequest
from zitadel_client.models.user_service_add_idp_link_response import UserServiceAddIDPLinkResponse
from zitadel_client.models.user_service_add_key_request import UserServiceAddKeyRequest
from zitadel_client.models.user_service_add_key_response import UserServiceAddKeyResponse
from zitadel_client.models.user_service_add_otp_email_request import UserServiceAddOTPEmailRequest
from zitadel_client.models.user_service_add_otp_email_response import UserServiceAddOTPEmailResponse
from zitadel_client.models.user_service_add_otpsms_request import UserServiceAddOTPSMSRequest
from zitadel_client.models.user_service_add_otpsms_response import UserServiceAddOTPSMSResponse
from zitadel_client.models.user_service_add_personal_access_token_request import UserServiceAddPersonalAccessTokenRequest
from zitadel_client.models.user_service_add_personal_access_token_response import UserServiceAddPersonalAccessTokenResponse
from zitadel_client.models.user_service_add_secret_request import UserServiceAddSecretRequest
from zitadel_client.models.user_service_add_secret_response import UserServiceAddSecretResponse
from zitadel_client.models.user_service_and_query import UserServiceAndQuery
from zitadel_client.models.user_service_any import UserServiceAny
from zitadel_client.models.user_service_auth_factor import UserServiceAuthFactor
from zitadel_client.models.user_service_auth_factor_state import UserServiceAuthFactorState
from zitadel_client.models.user_service_auth_factor_u2_f import UserServiceAuthFactorU2F
from zitadel_client.models.user_service_auth_factors import UserServiceAuthFactors
from zitadel_client.models.user_service_authentication_method_type import UserServiceAuthenticationMethodType
from zitadel_client.models.user_service_byte_filter_method import UserServiceByteFilterMethod
from zitadel_client.models.user_service_connect_error import UserServiceConnectError
from zitadel_client.models.user_service_create_invite_code_request import UserServiceCreateInviteCodeRequest
from zitadel_client.models.user_service_create_invite_code_response import UserServiceCreateInviteCodeResponse
from zitadel_client.models.user_service_create_passkey_registration_link_request import UserServiceCreatePasskeyRegistrationLinkRequest
from zitadel_client.models.user_service_create_passkey_registration_link_response import UserServiceCreatePasskeyRegistrationLinkResponse
from zitadel_client.models.user_service_create_user_request import UserServiceCreateUserRequest
from zitadel_client.models.user_service_create_user_response import UserServiceCreateUserResponse
from zitadel_client.models.user_service_deactivate_user_request import UserServiceDeactivateUserRequest
from zitadel_client.models.user_service_deactivate_user_response import UserServiceDeactivateUserResponse
from zitadel_client.models.user_service_delete_user_metadata_request import UserServiceDeleteUserMetadataRequest
from zitadel_client.models.user_service_delete_user_metadata_response import UserServiceDeleteUserMetadataResponse
from zitadel_client.models.user_service_delete_user_request import UserServiceDeleteUserRequest
from zitadel_client.models.user_service_delete_user_response import UserServiceDeleteUserResponse
from zitadel_client.models.user_service_details import UserServiceDetails
from zitadel_client.models.user_service_display_name_query import UserServiceDisplayNameQuery
from zitadel_client.models.user_service_domain_query import UserServiceDomainQuery
from zitadel_client.models.user_service_email_query import UserServiceEmailQuery
from zitadel_client.models.user_service_first_name_query import UserServiceFirstNameQuery
from zitadel_client.models.user_service_form_data import UserServiceFormData
from zitadel_client.models.user_service_gender import UserServiceGender
from zitadel_client.models.user_service_get_user_by_id_request import UserServiceGetUserByIDRequest
from zitadel_client.models.user_service_get_user_by_id_response import UserServiceGetUserByIDResponse
from zitadel_client.models.user_service_hashed_password import UserServiceHashedPassword
from zitadel_client.models.user_service_human import UserServiceHuman
from zitadel_client.models.user_service_human_email import UserServiceHumanEmail
from zitadel_client.models.user_service_human_mfa_init_skipped_request import UserServiceHumanMFAInitSkippedRequest
from zitadel_client.models.user_service_human_mfa_init_skipped_response import UserServiceHumanMFAInitSkippedResponse
from zitadel_client.models.user_service_human_phone import UserServiceHumanPhone
from zitadel_client.models.user_service_human_profile import UserServiceHumanProfile
from zitadel_client.models.user_service_human_user import UserServiceHumanUser
from zitadel_client.models.user_service_id_filter import UserServiceIDFilter
from zitadel_client.models.user_service_idp_information import UserServiceIDPInformation
from zitadel_client.models.user_service_idp_intent import UserServiceIDPIntent
from zitadel_client.models.user_service_idpldap_access_information import UserServiceIDPLDAPAccessInformation
from zitadel_client.models.user_service_idp_link import UserServiceIDPLink
from zitadel_client.models.user_service_idpo_auth_access_information import UserServiceIDPOAuthAccessInformation
from zitadel_client.models.user_service_idpsaml_access_information import UserServiceIDPSAMLAccessInformation
from zitadel_client.models.user_service_in_user_emails_query import UserServiceInUserEmailsQuery
from zitadel_client.models.user_service_in_user_id_query import UserServiceInUserIDQuery
from zitadel_client.models.user_service_key import UserServiceKey
from zitadel_client.models.user_service_key_field_name import UserServiceKeyFieldName
from zitadel_client.models.user_service_keys_search_filter import UserServiceKeysSearchFilter
from zitadel_client.models.user_service_ldap_credentials import UserServiceLDAPCredentials
from zitadel_client.models.user_service_last_name_query import UserServiceLastNameQuery
from zitadel_client.models.user_service_list_authentication_factors_request import UserServiceListAuthenticationFactorsRequest
from zitadel_client.models.user_service_list_authentication_factors_response import UserServiceListAuthenticationFactorsResponse
from zitadel_client.models.user_service_list_authentication_method_types_request import UserServiceListAuthenticationMethodTypesRequest
from zitadel_client.models.user_service_list_authentication_method_types_response import UserServiceListAuthenticationMethodTypesResponse
from zitadel_client.models.user_service_list_details import UserServiceListDetails
from zitadel_client.models.user_service_list_idp_links_request import UserServiceListIDPLinksRequest
from zitadel_client.models.user_service_list_idp_links_response import UserServiceListIDPLinksResponse
from zitadel_client.models.user_service_list_keys_request import UserServiceListKeysRequest
from zitadel_client.models.user_service_list_keys_response import UserServiceListKeysResponse
from zitadel_client.models.user_service_list_passkeys_request import UserServiceListPasskeysRequest
from zitadel_client.models.user_service_list_passkeys_response import UserServiceListPasskeysResponse
from zitadel_client.models.user_service_list_personal_access_tokens_request import UserServiceListPersonalAccessTokensRequest
from zitadel_client.models.user_service_list_personal_access_tokens_response import UserServiceListPersonalAccessTokensResponse
from zitadel_client.models.user_service_list_query import UserServiceListQuery
from zitadel_client.models.user_service_list_user_metadata_request import UserServiceListUserMetadataRequest
from zitadel_client.models.user_service_list_user_metadata_response import UserServiceListUserMetadataResponse
from zitadel_client.models.user_service_list_users_request import UserServiceListUsersRequest
from zitadel_client.models.user_service_list_users_response import UserServiceListUsersResponse
from zitadel_client.models.user_service_lock_user_request import UserServiceLockUserRequest
from zitadel_client.models.user_service_lock_user_response import UserServiceLockUserResponse
from zitadel_client.models.user_service_login_name_query import UserServiceLoginNameQuery
from zitadel_client.models.user_service_machine import UserServiceMachine
from zitadel_client.models.user_service_machine_user import UserServiceMachineUser
from zitadel_client.models.user_service_metadata import UserServiceMetadata
from zitadel_client.models.user_service_metadata_key_filter import UserServiceMetadataKeyFilter
from zitadel_client.models.user_service_metadata_search_filter import UserServiceMetadataSearchFilter
from zitadel_client.models.user_service_metadata_value_filter import UserServiceMetadataValueFilter
from zitadel_client.models.user_service_nick_name_query import UserServiceNickNameQuery
from zitadel_client.models.user_service_not_query import UserServiceNotQuery
from zitadel_client.models.user_service_notification_type import UserServiceNotificationType
from zitadel_client.models.user_service_or_query import UserServiceOrQuery
from zitadel_client.models.user_service_organization import UserServiceOrganization
from zitadel_client.models.user_service_organization_id_query import UserServiceOrganizationIdQuery
from zitadel_client.models.user_service_pagination_request import UserServicePaginationRequest
from zitadel_client.models.user_service_pagination_response import UserServicePaginationResponse
from zitadel_client.models.user_service_passkey import UserServicePasskey
from zitadel_client.models.user_service_passkey_authenticator import UserServicePasskeyAuthenticator
from zitadel_client.models.user_service_passkey_registration_code import UserServicePasskeyRegistrationCode
from zitadel_client.models.user_service_password import UserServicePassword
from zitadel_client.models.user_service_password_reset_request import UserServicePasswordResetRequest
from zitadel_client.models.user_service_password_reset_response import UserServicePasswordResetResponse
from zitadel_client.models.user_service_personal_access_token import UserServicePersonalAccessToken
from zitadel_client.models.user_service_personal_access_token_field_name import UserServicePersonalAccessTokenFieldName
from zitadel_client.models.user_service_personal_access_tokens_search_filter import UserServicePersonalAccessTokensSearchFilter
from zitadel_client.models.user_service_phone_query import UserServicePhoneQuery
from zitadel_client.models.user_service_profile import UserServiceProfile
from zitadel_client.models.user_service_reactivate_user_request import UserServiceReactivateUserRequest
from zitadel_client.models.user_service_reactivate_user_response import UserServiceReactivateUserResponse
from zitadel_client.models.user_service_redirect_urls import UserServiceRedirectURLs
from zitadel_client.models.user_service_register_passkey_request import UserServiceRegisterPasskeyRequest
from zitadel_client.models.user_service_register_passkey_response import UserServiceRegisterPasskeyResponse
from zitadel_client.models.user_service_register_totp_request import UserServiceRegisterTOTPRequest
from zitadel_client.models.user_service_register_totp_response import UserServiceRegisterTOTPResponse
from zitadel_client.models.user_service_register_u2_f_request import UserServiceRegisterU2FRequest
from zitadel_client.models.user_service_register_u2_f_response import UserServiceRegisterU2FResponse
from zitadel_client.models.user_service_remove_idp_link_request import UserServiceRemoveIDPLinkRequest
from zitadel_client.models.user_service_remove_idp_link_response import UserServiceRemoveIDPLinkResponse
from zitadel_client.models.user_service_remove_key_request import UserServiceRemoveKeyRequest
from zitadel_client.models.user_service_remove_key_response import UserServiceRemoveKeyResponse
from zitadel_client.models.user_service_remove_otp_email_request import UserServiceRemoveOTPEmailRequest
from zitadel_client.models.user_service_remove_otp_email_response import UserServiceRemoveOTPEmailResponse
from zitadel_client.models.user_service_remove_otpsms_request import UserServiceRemoveOTPSMSRequest
from zitadel_client.models.user_service_remove_otpsms_response import UserServiceRemoveOTPSMSResponse
from zitadel_client.models.user_service_remove_passkey_request import UserServiceRemovePasskeyRequest
from zitadel_client.models.user_service_remove_passkey_response import UserServiceRemovePasskeyResponse
from zitadel_client.models.user_service_remove_personal_access_token_request import UserServiceRemovePersonalAccessTokenRequest
from zitadel_client.models.user_service_remove_personal_access_token_response import UserServiceRemovePersonalAccessTokenResponse
from zitadel_client.models.user_service_remove_phone_request import UserServiceRemovePhoneRequest
from zitadel_client.models.user_service_remove_phone_response import UserServiceRemovePhoneResponse
from zitadel_client.models.user_service_remove_secret_request import UserServiceRemoveSecretRequest
from zitadel_client.models.user_service_remove_secret_response import UserServiceRemoveSecretResponse
from zitadel_client.models.user_service_remove_totp_request import UserServiceRemoveTOTPRequest
from zitadel_client.models.user_service_remove_totp_response import UserServiceRemoveTOTPResponse
from zitadel_client.models.user_service_remove_u2_f_request import UserServiceRemoveU2FRequest
from zitadel_client.models.user_service_remove_u2_f_response import UserServiceRemoveU2FResponse
from zitadel_client.models.user_service_resend_email_code_request import UserServiceResendEmailCodeRequest
from zitadel_client.models.user_service_resend_email_code_response import UserServiceResendEmailCodeResponse
from zitadel_client.models.user_service_resend_invite_code_request import UserServiceResendInviteCodeRequest
from zitadel_client.models.user_service_resend_invite_code_response import UserServiceResendInviteCodeResponse
from zitadel_client.models.user_service_resend_phone_code_request import UserServiceResendPhoneCodeRequest
from zitadel_client.models.user_service_resend_phone_code_response import UserServiceResendPhoneCodeResponse
from zitadel_client.models.user_service_retrieve_identity_provider_intent_request import UserServiceRetrieveIdentityProviderIntentRequest
from zitadel_client.models.user_service_retrieve_identity_provider_intent_response import UserServiceRetrieveIdentityProviderIntentResponse
from zitadel_client.models.user_service_search_query import UserServiceSearchQuery
from zitadel_client.models.user_service_send_email_code_request import UserServiceSendEmailCodeRequest
from zitadel_client.models.user_service_send_email_code_response import UserServiceSendEmailCodeResponse
from zitadel_client.models.user_service_send_email_verification_code import UserServiceSendEmailVerificationCode
from zitadel_client.models.user_service_send_invite_code import UserServiceSendInviteCode
from zitadel_client.models.user_service_send_passkey_registration_link import UserServiceSendPasskeyRegistrationLink
from zitadel_client.models.user_service_send_password_reset_link import UserServiceSendPasswordResetLink
from zitadel_client.models.user_service_set_email_request import UserServiceSetEmailRequest
from zitadel_client.models.user_service_set_email_response import UserServiceSetEmailResponse
from zitadel_client.models.user_service_set_human_email import UserServiceSetHumanEmail
from zitadel_client.models.user_service_set_human_phone import UserServiceSetHumanPhone
from zitadel_client.models.user_service_set_human_profile import UserServiceSetHumanProfile
from zitadel_client.models.user_service_set_metadata_entry import UserServiceSetMetadataEntry
from zitadel_client.models.user_service_set_password import UserServiceSetPassword
from zitadel_client.models.user_service_set_password_request import UserServiceSetPasswordRequest
from zitadel_client.models.user_service_set_password_response import UserServiceSetPasswordResponse
from zitadel_client.models.user_service_set_phone_request import UserServiceSetPhoneRequest
from zitadel_client.models.user_service_set_phone_response import UserServiceSetPhoneResponse
from zitadel_client.models.user_service_set_user_metadata_request import UserServiceSetUserMetadataRequest
from zitadel_client.models.user_service_set_user_metadata_response import UserServiceSetUserMetadataResponse
from zitadel_client.models.user_service_start_identity_provider_intent_request import UserServiceStartIdentityProviderIntentRequest
from zitadel_client.models.user_service_start_identity_provider_intent_response import UserServiceStartIdentityProviderIntentResponse
from zitadel_client.models.user_service_state_query import UserServiceStateQuery
from zitadel_client.models.user_service_text_filter_method import UserServiceTextFilterMethod
from zitadel_client.models.user_service_text_query_method import UserServiceTextQueryMethod
from zitadel_client.models.user_service_timestamp_filter import UserServiceTimestampFilter
from zitadel_client.models.user_service_timestamp_filter_method import UserServiceTimestampFilterMethod
from zitadel_client.models.user_service_type import UserServiceType
from zitadel_client.models.user_service_type_query import UserServiceTypeQuery
from zitadel_client.models.user_service_unlock_user_request import UserServiceUnlockUserRequest
from zitadel_client.models.user_service_unlock_user_response import UserServiceUnlockUserResponse
from zitadel_client.models.user_service_update_human_user_request import UserServiceUpdateHumanUserRequest
from zitadel_client.models.user_service_update_human_user_response import UserServiceUpdateHumanUserResponse
from zitadel_client.models.user_service_update_user_request import UserServiceUpdateUserRequest
from zitadel_client.models.user_service_update_user_response import UserServiceUpdateUserResponse
from zitadel_client.models.user_service_user import UserServiceUser
from zitadel_client.models.user_service_user_field_name import UserServiceUserFieldName
from zitadel_client.models.user_service_user_name_query import UserServiceUserNameQuery
from zitadel_client.models.user_service_user_state import UserServiceUserState
from zitadel_client.models.user_service_verify_email_request import UserServiceVerifyEmailRequest
from zitadel_client.models.user_service_verify_email_response import UserServiceVerifyEmailResponse
from zitadel_client.models.user_service_verify_invite_code_request import UserServiceVerifyInviteCodeRequest
from zitadel_client.models.user_service_verify_invite_code_response import UserServiceVerifyInviteCodeResponse
from zitadel_client.models.user_service_verify_passkey_registration_request import UserServiceVerifyPasskeyRegistrationRequest
from zitadel_client.models.user_service_verify_passkey_registration_response import UserServiceVerifyPasskeyRegistrationResponse
from zitadel_client.models.user_service_verify_phone_request import UserServiceVerifyPhoneRequest
from zitadel_client.models.user_service_verify_phone_response import UserServiceVerifyPhoneResponse
from zitadel_client.models.user_service_verify_totp_registration_request import UserServiceVerifyTOTPRegistrationRequest
from zitadel_client.models.user_service_verify_totp_registration_response import UserServiceVerifyTOTPRegistrationResponse
from zitadel_client.models.user_service_verify_u2_f_registration_request import UserServiceVerifyU2FRegistrationRequest
from zitadel_client.models.user_service_verify_u2_f_registration_response import UserServiceVerifyU2FRegistrationResponse
from zitadel_client.models.web_key_service_activate_web_key_request import WebKeyServiceActivateWebKeyRequest
from zitadel_client.models.web_key_service_activate_web_key_response import WebKeyServiceActivateWebKeyResponse
from zitadel_client.models.web_key_service_any import WebKeyServiceAny
from zitadel_client.models.web_key_service_connect_error import WebKeyServiceConnectError
from zitadel_client.models.web_key_service_create_web_key_request import WebKeyServiceCreateWebKeyRequest
from zitadel_client.models.web_key_service_create_web_key_response import WebKeyServiceCreateWebKeyResponse
from zitadel_client.models.web_key_service_delete_web_key_request import WebKeyServiceDeleteWebKeyRequest
from zitadel_client.models.web_key_service_delete_web_key_response import WebKeyServiceDeleteWebKeyResponse
from zitadel_client.models.web_key_service_ecdsa import WebKeyServiceECDSA
from zitadel_client.models.web_key_service_ecdsa_curve import WebKeyServiceECDSACurve
from zitadel_client.models.web_key_service_list_web_keys_response import WebKeyServiceListWebKeysResponse
from zitadel_client.models.web_key_service_rsa import WebKeyServiceRSA
from zitadel_client.models.web_key_service_rsa_bits import WebKeyServiceRSABits
from zitadel_client.models.web_key_service_rsa_hasher import WebKeyServiceRSAHasher
from zitadel_client.models.web_key_service_state import WebKeyServiceState
from zitadel_client.models.web_key_service_web_key import WebKeyServiceWebKey



from typing import Dict

from zitadel_client.auth.authenticator import Authenticator


class NoAuthAuthenticator(Authenticator):
    """
    A simple authenticator that performs no authentication.

    This authenticator is useful for cases where no token or credentials are required.
    It simply returns an empty dictionary for authentication headers.
    """

    def __init__(self, host: str = "http://localhost"):
        """
        Initializes the NoAuthAuthenticator with a default host.

        :param host: The base URL for the service. Defaults to "http://localhost".
        """
        super().__init__(host)

    def get_auth_headers(self) -> Dict[str, str]:
        """
        Returns an empty dictionary since no authentication is performed.

        :return: An empty dictionary.
        """
        return {}
